package com.unis.app.config;


import com.unis.accountability.businessmanagement.common.vo.cityFf.UserDTO;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.DepartmentDTO;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.OrgainzeDTO;
import com.unis.common.utils.ResponseWrapper;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Auther:张新亮
 * @Date: 2019/2/19 0019 12:37
 * @Description:
 */
@FeignClient(name = "myuser")
@Component
public interface MyUserClient {

    /**
     *  粮食安全行政首长责任制----获取组织部门列表----获取省级外部门
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/department/findByOrgCode")
    ResponseWrapper findByOrgCode(@RequestParam(value = "orgCode")String orgCode);
    /**
     * 获取省市所有部门信息--非树
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/department/getAllDept")
    ResponseWrapper getAllDept();

    /**
     *  粮食安全行政首长责任制----根据行政区划code查询单位信息
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/org/findByDepartmentAreaCode")
    ResponseWrapper findByDepartmentAreaCode(@RequestParam(value = "areaCode") String areaCode);

    /**
     * 根据父节点获取信息
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/department/getParentData")
    ResponseWrapper getParentData(@RequestParam(value = "parentCode") String parentCode);

    /**
     * 根据行政区划和机构类型查询机构
     * @param areaCode
     * @param type
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/org/findByAreaCodeAndOrgType/{areaCode}/{type}")
    ResponseWrapper findByAreaCodeAndOrgType( @PathVariable("areaCode")String areaCode,  @PathVariable("type")String type);

    /**
     * 查询本部门下所有人员
     * @param userDTO
     * @param page
     * @param size
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/user/findByDeptCode/{page}/{size}")
    ResponseWrapper findByDeptCode(@RequestBody UserDTO userDTO, @PathVariable("page") Integer page, @PathVariable("size") Integer size);


    /**
     * 根据组织编号获取本单位名字
     * @param
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/org/findByCode")
    ResponseWrapper findByCode(@RequestParam(value = "orgCode") String orgCode);

    /**
     *  粮食安全省长责任制--省市单位和外部部门 -----组织机构树
     * @param orgCode
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/org/getAllOrgDescendantsTree/1/10/{orgCode}")
    ResponseWrapper getAllOrgDescendantsTree(@PathVariable("orgCode")String orgCode);

    /**
     * 保存部门
     * @param departmentDTO
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/department/save")
    ResponseWrapper deptSave(@RequestBody DepartmentDTO departmentDTO);

    /**
     * 保存用户
     * @param type
     * @param userDTO
     */
    @RequestMapping(method = RequestMethod.POST, value = "/user/saveUserinfo/{type}")
    ResponseWrapper saveUserinfo(@PathVariable("type")String type,@RequestBody com.unis.accountability.businessmanagement.common.vo.msgNotice.UserDTO userDTO);

    /**
     * 保存机构
     * @param orgainzeDTO
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/org/add")
    ResponseWrapper orgSave(@RequestBody OrgainzeDTO orgainzeDTO);

    /**
     * 修改机构
     * @param orgainzeDTO
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/org/update")
    ResponseWrapper orgUpdate(@RequestBody OrgainzeDTO orgainzeDTO);


    /**
     * 根据组织名称查询组织信息
     * @param orgName
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/org/findByOrgName/{orgName}")
    ResponseWrapper findByOrgName(@PathVariable("orgName")String orgName);

    /***
     * 根据orgCode查询orgName
     * @param orgCode
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/org/orgNameByCode/{orgCode}")
    ResponseWrapper orgNameByCode(@PathVariable("orgCode")String orgCode);

    /**
     * 根据code查询用户
     * @param userCode
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/user/findByCode")
    ResponseWrapper findByUserCode(@RequestBody List<String> userCode);


    /**
     *根据登录名获取用户信息
     * @param userLoginName
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/user/findByUserloginname/{userLoginName}")
    ResponseWrapper findByUserloginname(@PathVariable("userLoginName") String userLoginName);

    /**
     * 根据部门名称查询部门信息
     * @param deptName
     * @param orgCode
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/department/findByDeptName")
    ResponseWrapper findByDeptName(@RequestParam(value = "deptName")String deptName, @RequestParam(value = "orgCode")String orgCode);

    /**
     * 保存部门信息
     * @param departmentDTO
     * @return
     */
    @RequestMapping(method = RequestMethod.POST, value = "/department/update")
    ResponseWrapper deptUpdate(DepartmentDTO departmentDTO);

    /**
     (get)传入单条code获取详情
     * @param deptCode
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/department/findByDeptCode")
    ResponseWrapper findByDeptCode1(@RequestParam(value = "deptCode")String deptCode);

    /**
     * 根据组织编号获取上级组织信息
     * @param orgId
     * @return
     */
    @RequestMapping(method = RequestMethod.GET, value = "/org/getParentOrg/{orgId}")
    ResponseWrapper getParentOrg(@RequestParam(value = "orgId")String orgId);

    @RequestMapping(method = RequestMethod.GET, value = "/user/findUserByAreaCode")
    ResponseWrapper findUserByAreaCode(@RequestBody List<String> userCode);
}



