package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPublishVO;
import com.unis.app.service.BizRespCityPhbmService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/cityPhbm")
@Slf4j
@Api(value = "粮食安全省长责任制--市级配合部门", tags = "粮食安全省长责任制--市级配合部门")
public class BizRespCityPhbmController {
    @Autowired
    private BizRespCityPhbmService bizRespCityPhbmService;


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody CityPhbmPage cityPhbmPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            Map result = bizRespCityPhbmService.findByPage(cityPhbmPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     *
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门----查看", notes = "参数：id  评分结果录入(州市)ID ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            CityTaskVO cityTaskVO=bizRespCityPhbmService.findById(id);
            return ResponseWrapper.success(200, "查询成功", cityTaskVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 更新--重点考核事项
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody PhbmVO phbmVO
    ) {
        try {
            ResponseWrapper responseWrapper =bizRespCityPhbmService.update(phbmVO);
            return responseWrapper;
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }





    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门---发布", notes = "参数：评分结果录入ID")
    @PostMapping(value = "/publish/{id}")
    public ResponseWrapper publish(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespCityPhbmService.publish(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门---批量发布", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody CityZpbmPublishVO cityZpbmPublishVO
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityPhbmService.publishALL(cityZpbmPublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门---提交比例", notes = "参数：")
    @GetMapping(value = "/findByTaskDistributionRatio/{year}")
    public ResponseWrapper findByTaskDistributionRatio(
            @PathVariable("year") String  year
    ) {
        try {
            Map map= bizRespCityPhbmService.findByTaskDistributionRatio(year);
            return ResponseWrapper.success(map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门---根据年份部门状态查询明细", notes = "参数：")
    @PostMapping(value = "/fidByYearAndDeptIdAndStatus")
    public ResponseWrapper fidByYearAndDeptIdAndStatus(
            @RequestBody CityPhbmPage cityPhbmPage
    ) {
        try {
            List<CityPhbmPageVO> zpbmVOList=bizRespCityPhbmService.fidByYearAndDeptIdAndStatus(cityPhbmPage);
            return ResponseWrapper.success(200, "查询成功", zpbmVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }




}