package com.unis.app.controller;

/**
 * @Auther:张新亮
 * @Date: 2019/9/20 0020 13:55
 * @Description:
 */

import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskDistributionVO;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskPage;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskPublishVO;
import com.unis.app.service.BizRespCityTaskDistributionService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/cityTaskDistribution")
@Slf4j
@Api(value = "粮食安全省长责任制--州市任务分配管理(市考核办)", tags = "粮食安全省长责任制--州市任务分配管理(市考核办)")
public class BizRespCityTaskDistributionController {
    @Autowired
    private BizRespCityTaskDistributionService bizRespCityTaskDistributionService;


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody CityTaskPage cityTaskPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            Map result = bizRespCityTaskDistributionService.findByPage(cityTaskPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     *
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            CityTaskDistributionVO cityVO=bizRespCityTaskDistributionService.findById(id);
            System.out.println("粮食安全行政首长责任制----州市任务分配管理----查看"+cityVO.toString());
            return ResponseWrapper.success(200, "查询成功", cityVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 更新--重点考核事项
     *
     * @param cityTaskUpdateVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody CityTaskDistributionVO cityTaskUpdateVO
    ) {
        try {
            ResponseWrapper update = bizRespCityTaskDistributionService.update(cityTaskUpdateVO);
            ResponseWrapper responseWrapper = update;
            return responseWrapper;
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }




    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)---发布", notes = "参数：")
    @PostMapping(value = "/publish/{id}")
    public ResponseWrapper publish(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespCityTaskDistributionService.publish(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)---批量发布", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody  CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityTaskDistributionService.publishALL(cityTaskPublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市任务分配管理(市考核办)---分配比例", notes = "参数：")
    @GetMapping(value = "/findByTaskDistributionRatio/{year}")
    public ResponseWrapper findByTaskDistributionRatio(
            @PathVariable("year") String  year
    ) {
        try {
            Map map= bizRespCityTaskDistributionService.findByTaskDistributionRatio(year);
            return ResponseWrapper.success(map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----区自评查看（市局）----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findZpCityByPage/{page}/{size}")
    public ResponseWrapper findZpCityByPage(
            @RequestBody CityTaskPage cityTaskPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            Map result = bizRespCityTaskDistributionService.findZpCityByPage(cityTaskPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----区自评查看（市局）---考核分发", notes = "参数：")
    @PostMapping(value = "/publishKhff")
    public ResponseWrapper publishKhff(
            @RequestBody  CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityTaskDistributionService.publishKhff(cityTaskPublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----区自评查看（市局）---是否考核分发", notes = "参数：")
    @PostMapping(value = "/findByIsKhff")
    public ResponseWrapper findByIsKhff(
            @RequestBody  CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityTaskDistributionService.findByIsKhff(cityTaskPublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

}