package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.cityFf.CityFfPage;
import com.unis.accountability.businessmanagement.common.vo.cityFf.FfPublishVO;
import com.unis.accountability.businessmanagement.common.vo.cityFf.FfVO;
import com.unis.accountability.businessmanagement.common.vo.cityFf.TaskFfInfoVO;
import com.unis.app.service.BizRespCityTaskfFService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/12/13 0013 15:23
 * @Description:
 */
@RestController
@RequestMapping("/cityTaskfF")
@Slf4j
@Api(value = "粮食安全省长责任制--评分表分处室考核（市部门）", tags = "粮食安全省长责任制--评分表分处室考核（市部门）")
public class BizRespCityTaskfFController {
    @Autowired
    private BizRespCityTaskfFService bizRespCityTaskfFService;



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody CityFfPage cityFfPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            Map result = bizRespCityTaskfFService.findByPage(cityFfPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     *
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）----查看", notes = "参数：id  评分结果录入(州市)ID ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            TaskFfInfoVO cityTaskVO=bizRespCityTaskfFService.findById(id);
            return ResponseWrapper.success(200, "查询成功", cityTaskVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 更新--重点考核事项
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制-----评分表分处室考核（市部门）---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody FfVO ffVO
    ) {
        try {
            ResponseWrapper responseWrapper =bizRespCityTaskfFService.update(ffVO);
            return responseWrapper;
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）---发布", notes = "参数：评分结果录入ID")
    @PostMapping(value = "/publish/{id}")
    public ResponseWrapper publish(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespCityTaskfFService.publish(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----市级配合部门---批量发布", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody FfPublishVO ffPublishVO
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityTaskfFService.publishALL(ffPublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----评分表分处室考核（市部门）--查询是否可以提交数据", notes = "参数：")
    @PostMapping(value = "/findByIsSubmit")
    public ResponseWrapper findByIsSubmit(
            @RequestBody FfPublishVO ffPublishVO
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityTaskfFService.findByIsSubmit(ffPublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

}