package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.CityPublishVO;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.ZpbmVO;
import com.unis.app.service.BizRespCityQtbmService;
import com.unis.app.service.BizRespCityZpbmService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**州市任务分配管理
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/cityZpbm")
@Slf4j
@Api(value = "粮食安全省长责任制--市级自评部门", tags = "粮食安全省长责任制--市级自评部门")
public class BizRespCityZpbmController {
    @Autowired
    private BizRespCityZpbmService bizRespCityZpbmService;
    @Autowired
    private BizRespCityQtbmService bizRespCityQtbmService;

    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody CityZpbmPage cityZpbmPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            Map result = bizRespCityZpbmService.findByPage(cityZpbmPage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     *
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核----查看", notes = "参数：id  评分结果录入(州市)ID ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            CityTaskVO cityTaskVO=bizRespCityQtbmService.findById(id);
            return ResponseWrapper.success(200, "查询成功", cityTaskVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 更新--重点考核事项
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody ZpbmVO zpbmVO
    ) {
        try {
            ResponseWrapper responseWrapper =bizRespCityZpbmService.update(zpbmVO);
            return responseWrapper;
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }





    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核---发布", notes = "参数：评分结果录入ID")
    @GetMapping(value = "/publish/{id}")
    public ResponseWrapper publish(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespCityZpbmService.publish(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核---批量发布", notes = "参数：")
    @GetMapping(value = "/publishALL/{year}")
    public ResponseWrapper publishALL(
            @PathVariable("year") String  year
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityZpbmService.publishALL(year);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }
    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核---批量发布", notes = "参数：")
    @GetMapping(value = "/publishALL/{year}/{status}")
    public ResponseWrapper publishALLByStatus(
            @PathVariable("year") String  year,
            @PathVariable("status") String  status
    ) {
        try {
            ResponseWrapper responseWrapper=  bizRespCityZpbmService.publishALL(year,status);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核---提交比例", notes = "参数：")
    @GetMapping(value = "/findByTaskDistributionRatio/{year}/{type}/{areaCode}")
    public ResponseWrapper findByTaskDistributionRatio(
            @PathVariable("year") String  year,
            @PathVariable("type") String  type,
            @PathVariable("areaCode") String  areaCode
    ) {
        try {
            Map map= bizRespCityZpbmService.findByTaskDistributionRatio(year,type,areaCode);
            return ResponseWrapper.success(map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

    /**
     * 粮食安全行政首长责任制----州市自评部门审核---更新状态，用于市评分审核审核
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核---更新状态，用于市评分审核审核", notes = "参数：")
    @PostMapping(value = "/updateStatus")
    public ResponseWrapper updateStatus(
            @RequestBody CityPublishVO cityPublishVO
    ) {
        try {
            bizRespCityZpbmService.updateStatus(cityPublishVO);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----州市自评部门审核---根据年份部门状态查询明细", notes = "参数：")
    @PostMapping(value = "/fidByYearAndDeptIdAndStatus")
    public ResponseWrapper fidByYearAndDeptIdAndStatus(
            @RequestBody CityZpbmPage cityZpbmPage
    ) {
        try {
            List<CityZpbmPageVO> zpbmVOList=bizRespCityZpbmService.fidByYearAndDeptIdAndStatus(cityZpbmPage);
            return ResponseWrapper.success(200, "查询成功", zpbmVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }
}