package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentPage;
import com.unis.accountability.businessmanagement.common.vo.examinationContent.ContentVO;
import com.unis.app.service.BizRespExaminationContentService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;


/**考核内容
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 10:13
 * @Description:
 */
@RestController
@RequestMapping("/examinationContent")
@Slf4j
@Api(value = "粮食安全行政首长责任制----考核内容", tags = "粮食安全省长责任制--考核内容")
public class BizRespExaminationContentController {

    @Autowired
    private BizRespExaminationContentService bizRespExaminationContentService;

    /**
     * 保存数据 考核内容
     *
     * @param contentVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----保存", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody ContentVO contentVO
    ) {
        System.out.println("保存=====考核内容==="+contentVO.toString());
        try {
            ResponseWrapper responseWrapper = bizRespExaminationContentService.save(contentVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }





    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody ContentPage contentPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespExaminationContentService.findByPage(contentPage, page, size);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }



    /**
     * 更新考核内容
     *
     * @param contentVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----修改", notes = "参数：bizRespExaminationContentVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody ContentVO contentVO
    ) {

        try {
            ResponseWrapper responseWrapper = bizRespExaminationContentService.update(contentVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error(500, "操作失败",null);
        }

    }



    /**
     * 多选删除
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----删除", notes = "参数：考核内容ids(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody String[] ids) {
        try {
            ResponseWrapper responseWrapper = bizRespExaminationContentService.deletes(ids);
            return responseWrapper;
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "考核内容删除失败",null);
        }
    }


    /**
     * 查询考核内容
     * @param year 年份
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核内容----下拉框", notes = "参数：year ")
    @GetMapping(value = "/findByYearAndOrgId/{year}/{responsibilityId}")
    public ResponseWrapper findByYearAndOrgId(
            @PathVariable("year") String  year,
            @PathVariable("responsibilityId") String  responsibilityId
    ) {
        if (null == year ) {
            return ResponseWrapper.success(320, "请求参数不能为空", null);
        }else{
            try {
                ResponseWrapper responseWrapper=bizRespExaminationContentService.findByYearAndOrgId(year,responsibilityId);
                return responseWrapper;
            } catch (Exception e) {
                e.printStackTrace();
                log.error("查找对象，发生异常", e.getMessage());
                return ResponseWrapper.error(500, "单位信息查询失败", null);
            }

        }
    }



}