package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.examinationExcel.AreeExcelVO;
import com.unis.app.service.BizRespExaminationExcelService;
import com.unis.app.service.BizRespFileService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.Map;

/**excel导入导出
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 15:22
 * @Description:
 */
@RestController
@RequestMapping("/examinationExcel")
@Slf4j
@Api(value = "粮食安全省长责任制--excel导入导出", tags = "粮食安全省长责任制--excel导入导出")
public class BizRespExaminationExcelController {

    @Autowired
    private BizRespExaminationExcelService bizRespExaminationExcelService;
    @Autowired
    private BizRespFileService bizRespFileService;



    /**
     * 20200225 修改：通用模板不需要添加年度筛选
     */
    @ApiOperation(value = "粮食安全行政首长责任制--考核评分表管理---下载模板", notes = "参数：文件")
    @GetMapping(value = "/downloadKhpfbExcel")
    public void downloadKhpfbExcel(HttpServletResponse response ) {
        try {
            bizRespExaminationExcelService.downloadKhpfbExcel(response);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "上传文件，发生异常", e.getMessage() );
        }
    }




    /**
     * 粮食安全行政首长责任制----考核评分表管理----导入评分表
     * @return
     * @author 张新亮
     * 文件上传
     * @date 2018/6/28 18:25
     */
    @ApiOperation(value = "粮食安全行政首长责任制----考核评分表管理----导入评分表", notes = "参数：文件")
    @RequestMapping(value = "/importKhpfbExcel/{year}/{pfbmc}",method = RequestMethod.POST, consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    @ResponseBody
    public ResponseWrapper importKhpfbExcel(
            @RequestBody MultipartFile file,
            @PathVariable("year") String year,
            @PathVariable("pfbmc") String pfbmc
    ) {
        try {
            String errorMsg = "";
            String fileType = "";
            System.out.println("year="+year);
            Map<String, Object> result =new HashMap();
            String fileName = file.getOriginalFilename();
            String[] strArray = fileName.split("\\.");
            int suffixIndex = strArray.length -1;
            fileType =strArray[suffixIndex];
            if(fileType.equals("xls") || fileType.equals("xlsx")){
                result = bizRespExaminationExcelService.importKhpfbExcel(file, year, pfbmc,fileType);
                String re=result.get("result").toString();
                String mes=result.get("mes").toString();
                if(re.equals("1")){
                    return ResponseWrapper.success( 200, "文件上传成功", result);
                }else{
                    return ResponseWrapper.error(504, mes,null);
                }
            }else{
                errorMsg="excel文件类型不对，应为.xls";
                return ResponseWrapper.error(504, errorMsg,null);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "上传文件，发生异常", e.getMessage() );
            return ResponseWrapper.error( 412, "文件上传失败！" ,null);
        }
    }





    @ApiOperation(value = "粮食安全行政首长责任制----评分表设置（市局）----导出评分表", notes = "参数：文件")
    @GetMapping(value = "/exportKhpfbExcel/{bizRespResponsibilityId}")
    public void exportKhpfbExcel(
            HttpServletResponse response,
            @PathVariable("bizRespResponsibilityId") String bizRespResponsibilityId

    ) {
        try {
            bizRespExaminationExcelService.exportKhpfbExcel(response, bizRespResponsibilityId);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "上传文件，发生异常", e.getMessage() );
        }
    }



    @ApiOperation(value = "粮食安全行政首长责任制--区自评查看（区粮办）---导出", notes = "参数：文件")
    @GetMapping(value = "/exportAreaExcel")
    public void exportAreaExcel(
            HttpServletResponse response,
            String year,
            String qtbm,
            String phbm,
            String areaCode,
            Integer tag
    ) {
        AreeExcelVO areeExcelVO =new AreeExcelVO();
        areeExcelVO.setYear(year);
        areeExcelVO.setQtbm(qtbm);
        areeExcelVO.setPhbm(phbm);
        areeExcelVO.setAreaCode(areaCode);
        System.out.println("==================粮食安全行政首长责任制--区自评查看（区粮办）---导出===========");
        System.out.println(areeExcelVO.toString());
        System.out.println("==================粮食安全行政首长责任制--区自评查看（区粮办）---导出===========");
        try {
            bizRespExaminationExcelService.exportAreaExcel(response, areeExcelVO, tag);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "上传文件，发生异常", e.getMessage() );
        }
    }











    @ApiOperation(value = "信息报送-------文件下载", notes = "参数：文件")
    @GetMapping(value = "/downloadMsgNotice/{id}")
    public void downloadMsgNotice(
            HttpServletResponse response,
            @PathVariable("id") String id

    ) {
        try {
            bizRespFileService.downloadMsgNotice(response, id);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "上传文件，发生异常", e.getMessage() );
        }
    }


}