package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.examinationItem.ItemPage;
import com.unis.accountability.businessmanagement.common.vo.examinationItem.ItemVO;
import com.unis.app.service.BizRespExaminationItemService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;



/**重点考核事项
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 15:22
 * @Description:
 */
@RestController
@RequestMapping("/examinationItem")
@Slf4j
@Api(value = "粮食安全行政首长责任制----重点考核事项", tags = "粮食安全省长责任制--重点考核事项")
public class BizRespExaminationItemController {
    @Autowired
    private BizRespExaminationItemService bizRespExaminationItemService;




    /**
     * 粮食安全行政首长责任制----重点考核事项---保存
     *
     * @param itemVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----重点考核事项---保存", notes = "参数：重点考核事项 itemVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody ItemVO itemVO
    ) {
        System.out.println("保存=====重点考核事项==="+itemVO.toString());
        try {
            ResponseWrapper responseWrapper = bizRespExaminationItemService.save(itemVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----重点考核事项---分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody ItemPage itemPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespExaminationItemService.findByPage(itemPage, page, size);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }





    /**
     * 更新--重点考核事项
     *
     * @param itemVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----重点考核事项---编辑", notes = "参数：itemVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody ItemVO itemVO
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespExaminationItemService.update(itemVO);
            return responseWrapper;
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }

    }



    /**
     * 多选删除
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----重点考核事项---批量删除", notes = "参数：重点考核事项ids(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody  String[] ids) {
        try {
            ResponseWrapper responseWrapper = bizRespExaminationItemService.deletes(ids);
            return responseWrapper;
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "重点考核事项删除失败",null);
        }
    }





    /**
     * 查询重点考核事项
     * @param year 年份
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----重点考核事项---根据年份year和组织机构 orgId 查询重点考核事项", notes = "参数：year ")
    @GetMapping(value = "/findByYearAndOrgId/{year}/{responsibilityId}")
    public ResponseWrapper findByYearAndOrgId(
            @PathVariable("year") String  year,
            @PathVariable("responsibilityId") String  responsibilityId

    ) {
        if (null == year ) {
            return ResponseWrapper.success(320, "请求参数不能为空", null);
        }else{
            try {
                ResponseWrapper responseWrapper=bizRespExaminationItemService.findByYearAndOrgId(year,responsibilityId);
                return responseWrapper;
            } catch (Exception e) {
                e.printStackTrace();
                log.error("查找对象，发生异常", e.getMessage());
                return ResponseWrapper.error(500, "单位信息查询失败", null);
            }

        }
    }










}