package com.unis.app.controller;

import com.unis.accountability.businessmanagement.client.BizRespExaminationTaskClient;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskInfoVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskPageVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskVO;
import com.unis.app.service.BizRespExaminationTaskService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**考核目标任务
 * @Auther:张新亮
 * @Date: 2018/11/1 0001 17:58
 * @Description:
 */
@RestController
@RequestMapping("/examinationTask")
@Slf4j
@Api(value = "粮食安全省长责任制--考核目标任务", tags = "粮食安全省长责任制--考核目标任务")
public class BizRespExaminationTaskController {

    @Autowired
    private BizRespExaminationTaskService bizRespExaminationTaskService;

    @Autowired
    private BizRespExaminationTaskClient bizRespExaminationTaskClient;


    /**
     * 根据 考核指标 id 查询 考核目标任务 可填分数
     * @param
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---查询可填分数", notes = "参数：year ")
    @GetMapping(value = "/findBySorce/{quotaId}/{responsibilityId}")
    public ResponseWrapper findBySorce(
            @PathVariable("quotaId") String  quotaId,
            @PathVariable("responsibilityId") String  responsibilityId
    ) {
        try {

            ResponseWrapper responseWrapper=bizRespExaminationTaskService.findBySorce(quotaId,responsibilityId);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     * 考核目标任务
     *
     * @param taskVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---保存", notes = "参数：考核目标任务 taskVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody TaskVO taskVO
    ) {
        System.out.println("保存=====考核指标==="+taskVO.toString());
        try {
            ResponseWrapper responseWrapper= bizRespExaminationTaskService.save(taskVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---分页", notes = "默认参数：source= :1 管理平台用    deptIds   " +
            "2 userId : 配合部门，牵头部门 3 userId :自评部门  4:根据行政区划查询所有数据,statusType=10,20,  year=2018"
    )
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody TaskPageVO taskPageVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            Map result = bizRespExaminationTaskService.findByPage(taskPageVO, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }







    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespExaminationTaskService.findById(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细--省市--牵头部门配合部门部门和自评部门专用", notes = "参数：id ")
    @GetMapping(value = "/findByTaskInfo/{id}")
    public ResponseWrapper findByTaskInfo(
            @PathVariable("id") String  id
    ) {
        try {
            TaskInfoVO taskInfoVO=bizRespExaminationTaskService.findByTaskInfo(id);
            return ResponseWrapper.success(200, "查询成功", taskInfoVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }





    /**
     * 更新--考核目标任务
     *
     * @param taskVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---编辑", notes = "参数：taskVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody TaskVO taskVO
    ) {
        try {
            ResponseWrapper responseWrapper= bizRespExaminationTaskService.update(taskVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }


    /**
     * 更新--考核目标任务
     *
     * @param taskVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---编辑", notes = "参数：taskVO")
    @PostMapping(value = "/updateByinputId")
    public ResponseWrapper updateByinputId(
            @RequestBody TaskVO taskVO
    ) {
        try {
            ResponseWrapper responseWrapper= bizRespExaminationTaskService.updateOpinion(taskVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }

    @ApiOperation(value = "粮食安全省长责任制--区考核科室分配", notes = "参数：orgName")
    @PostMapping(value = "/publishAll")
    public ResponseWrapper publishAll() {
        try {
            ResponseWrapper responseWrapper = bizRespExaminationTaskClient.publishAll(CurrentUtil.getOrgId());
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }
    /**
     * 多选删除
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--考核目标任务---批量删除", notes = "参数：考核目标任务ids(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(
            @RequestBody   String[] ids
    ) {
        try {
            ResponseWrapper responseWrapper= bizRespExaminationTaskService.deletes(ids);
            return responseWrapper;
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败",null);
        }
    }






}