package com.unis.app.controller;


import com.unis.accountability.businessmanagement.common.vo.responsibility.*;
import com.unis.app.service.BizRespResponsibilityService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


/**
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:38
 * @Description:
 */
@RestController
@Slf4j
@Api(value = "粮食安全行政首长责任制-----考核评分表管理", tags = "粮食安全行政首长责任制：考核评分表管理")
@RequestMapping("/responsibility")
public class BizRespResponsibilityController {

    @Autowired
    private BizRespResponsibilityService bizRespResponsibilityService;

    private static String title="粮食安全行政首长责任制-----考核评分表管理";


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "考核评分表管理---分页查询", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody BizRespResponsibilityPageVO pageVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespResponsibilityService.findByPage(pageVO, page, size);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error(title+"分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, title+"查询失败",null);
        }
    }



    /**
     * 考核评分表管理------根据评分表名称和年分查询数据是否存在
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理------根据评分表名称和年分查询数据是否存在", notes = "参数：下发评表明细 pageVO")
    @PostMapping(value = "/findByPfbmc")
    public ResponseWrapper findByPfbmc(
            @RequestBody BizRespResponsibilityPfbmcVO pfbmcVO
    ) {
        try {
            ResponseWrapper responseWrapper =bizRespResponsibilityService.findByPfbmc(pfbmcVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error(title+"，发生异常", e.getMessage());
            return ResponseWrapper.error(500, title+"查询失败",null);
        }
    }



    /**
     * 考核评分表管理------根据id查询明细
     * @param
     * @param
     * @return
     */


    @ApiOperation(value = "根据年份year和组织机构", notes = "参数：year ")
    @GetMapping(value = "/findById/{year}/{id}")
    public ResponseWrapper findByYearAndOrgId(
            @PathVariable("year") String  year,
            @PathVariable("id") String  id
    ) {
        if (null == year) {
            return ResponseWrapper.success(320, "请求参数不能为空", null);
        }else{
            try {
                ResponseWrapper responseWrapper=bizRespResponsibilityService.findById(year, id);
                return responseWrapper;
            } catch (Exception e) {
                e.printStackTrace();
                log.error("查找对象，发生异常", e.getMessage());
                return ResponseWrapper.error(500, "单位信息查询失败", null);
            }

        }
    }



    /**
     * 查询责任考核
     * @param
     * @param
     * @return
     */
    @ApiOperation(value = "考核评分表管理----根据id查询明细", notes = "参数：id ")
    @GetMapping(value = "/findByIds/{id}")
    public ResponseWrapper findByIds(
            @PathVariable("id") String  id
    ) {

        try {
            BizRespResponsibilityVO bizRespResponsibilityVO=bizRespResponsibilityService.findByIds(id);
            return ResponseWrapper.success(200, "查询成功", bizRespResponsibilityVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }

    }






    /**
     * 考核评分表管理------根据id查询明细
     * @param
     * @param
     * @return
     */


    @ApiOperation(value = "考核评分表管理------根据ID查询基本信息", notes = "参数：year ")
    @GetMapping(value = "/findByInfo/{id}")
    public ResponseWrapper findByInfo(
            @PathVariable("id") String  id
    ) {
        try {
            BizRespResponsibilityVO bizRespResponsibilityVO=bizRespResponsibilityService.findByInfo(id);
            return ResponseWrapper.success(200, "查询成功", bizRespResponsibilityVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败", null);
        }
    }


    /**
     * 考核评分表管理---保存
     *
     * @param bilityVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---保存", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody BilityVO bilityVO
    ) {
        System.out.println("保存=====责任考核==="+bilityVO.toString());
        try {
            ResponseWrapper responseWrapper= bizRespResponsibilityService.save(bilityVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }




    /**
     * 考核评分表管理---编辑
     *
     * @param bilityVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---编辑", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/updtae")
    public ResponseWrapper updtae(
            @RequestBody BilityVO bilityVO
    ) {
        System.out.println("编辑=====责任考核==="+bilityVO.toString());
        try {
            ResponseWrapper responseWrapper= bizRespResponsibilityService.updtae(bilityVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }




    /**
     * 单选删除
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理------删除责任考核", notes = "参数：考核内容id(可传入多个)")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody String ids) {
        try {
            ResponseWrapper responseWrapper = bizRespResponsibilityService.deletes(ids);
            return responseWrapper;
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败",null);
        }
    }



    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---发布", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody PublishVO publishVO

    ) {
        try {
            System.out.println("====================接收参数==============");
            System.out.println(publishVO.toString());
            System.out.println("====================接收参数==============");
            ResponseWrapper responseWrapper = bizRespResponsibilityService.publish(publishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }




    /**
     * 下及州市
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---下级州市", notes = "参数：下及州市 pageVO")
    @PostMapping(value = "/findByRespResponsibilityCity")
    public ResponseWrapper findByRespResponsibilityCity(
            @RequestBody BizRespResponsibilityCityVO cityVO
    ) {
        try {
            Map result= bizRespResponsibilityService.findByRespResponsibilityCity(cityVO);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.success(200, "保存成功",null);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    /**
     * 下及州市
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---更新评分表", notes = "参数：下及州市 pageVO")
    @PostMapping(value = "/updatePfb")
    public ResponseWrapper updatePfb(
            @RequestBody BizRespResponsibilityUpdateVO updateVO
    ) {
        try {
            ResponseWrapper responseWrapper =bizRespResponsibilityService.updatePfb(updateVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 下发评表
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理---下发评表明细", notes = "参数：下发评表明细 pageVO")
    @PostMapping(value = "/findByRespResponsibilityInfo")
    public ResponseWrapper findByRespResponsibilityInfo(
            @RequestBody BizRespResponsibilityPageVO pageVO
    ) {
        try {
            ResponseWrapper responseWrapper= bizRespResponsibilityService.findByRespResponsibilityInfo(pageVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 下发评表
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "考核评分表管理------复制评分表", notes = "参数：下发评表明细 pageVO")
    @PostMapping(value = "/saveCopyPfb")
    public ResponseWrapper saveCopyPfb(
            @RequestBody BizRespCopyPfbVO copyPfbVO
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespResponsibilityService.saveCopyPfb(copyPfbVO);
            return responseWrapper;
        } catch (Exception e) {
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     * 考核评分权重--查询可选年分
     * @return
     */
    @ApiOperation(value = "考核评分表管理---市状态", notes = "  ")
    @GetMapping(value = "/findByCityStatus")
    public ResponseWrapper findByCityStatus(
    ) {
        try {
            List<Map> mapList=bizRespResponsibilityService.findByStatus();
            return ResponseWrapper.success(200, "保存成功",mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


}