package com.unis.app.controller;

import com.unis.accountability.businessmanagement.client.BizRespScoreInputClient;
import com.unis.accountability.businessmanagement.common.vo.cityQtbm.CityTaskinfoVO;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskPublishVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BizRespExaminationTaskVO;
import com.unis.accountability.businessmanagement.common.vo.provinceTask.ProvinceTaskPage;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputSmiitVO;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityPageVO;
import com.unis.app.service.BizRespScoreInputService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Auther:张新亮
 * @Date: 2019/9/19 0019 15:42
 * @Description:
 */
@RestController
@RequestMapping("/respScoreInput")
@Slf4j
@Api(value = "粮食安全首长责任制--州市考核任务管理", tags = "粮食安全首长责任制--州市考核任务管理")
public class BizRespScoreInputController {
    @Autowired
    private BizRespScoreInputService bizRespScoreInputService;

    @Autowired
    private BizRespScoreInputClient client;
    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市考核任务管理----发布", notes = "参数：")
    @GetMapping(value = "/publish/{id}")
    public ResponseWrapper publish(
            @PathVariable("id") String id
    ) {
        try {
            bizRespScoreInputService.publish(id);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市考核任务管理  根据年分 状态 行政区划 查询 州市考核录入数据", notes = "参数：")
    @PostMapping(value = "/findByYearAndStatusAndAreaCode")
    public ResponseWrapper findByYearAndStatusAndAreaCode(
            @RequestBody CityTaskPublishVO cityTaskPublishVO
    ) {
        try {
            List<BizRespScoreInputVO> inputList= bizRespScoreInputService.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
            return ResponseWrapper.success(inputList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--下发州市考核任务----制定州市考核任务--- 分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findTaskByPage/{page}/{size}")
    public ResponseWrapper findTaskByPage(
            @RequestBody BizRespResponsibilityPageVO bizRespResponsibilityPageVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespScoreInputService.findByPage(bizRespResponsibilityPageVO, page, size);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }


    /**
     *
     * @param taskId 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全行政首长责任制----区级配合部门 牵头部门 ----查看", notes = "参数：id ")
    @GetMapping(value = "/findByQtbmAndPhbmAndZpbm/{taskId}/{areaCode}")
    public ResponseWrapper findByQtbmAndPhbmAndZpbm(
            @PathVariable("taskId") String  taskId,
            @PathVariable("areaCode") String areaCode
    ) {
        try {
            CityTaskinfoVO cityTaskVO=bizRespScoreInputService.findByQtbmAndPhbmAndZpbm(taskId, areaCode);
            return ResponseWrapper.success(200, "查询成功", cityTaskVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }



    /**
     * 州市、外部单位牵头部门、配合部门评分--查询是否可以提交数据
     * @return
     */
    @ApiOperation(value = "州市、外部单位牵头部门、配合部门评分--查询是否可以提交数据", notes = "参数：type 类型:10 省配合部门 20 省牵头部门 30 市自评部门 40 市配合部门 50 市牵头部门 60 省级平时牵头部门  70 省级平时配合部门 80 州市任务分配管理(市考核办)")
    @PostMapping(value = "/findByIsSubmit")
    public ResponseWrapper findByIsSubmit(
            @RequestBody BizRespScoreInputSmiitVO scoreInputSmiitVO
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoreInputService.findByIsSubmit( scoreInputSmiitVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    @ApiOperation(value = "粮食安全首长责任制--结果汇总查看----发布", notes = "参数：")
    @PostMapping(value = "/publishByArea")
    public ResponseWrapper publishByArea(
            @RequestBody ProvinceTaskPage provinceTaskPage
    ) {
        try {
            ResponseWrapper responseWrapper = client.publishByArea(provinceTaskPage);
            return ResponseWrapper.success();
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }
    @ApiOperation(value = "粮食安全首长责任制--区分科室考核-根据id查询", notes = "参数：inputId")
    @GetMapping(value = "/{id}")
    public ResponseWrapper findByInputId(
            @PathVariable("id") String id
    ) {
        try {
            BizRespExaminationTaskVO byId = bizRespScoreInputService.findByInputId(id);
            return ResponseWrapper.success(byId);
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }
}