package com.unis.app.controller;


import com.unis.accountability.businessmanagement.common.vo.scoringCity.CityVO;
import com.unis.accountability.businessmanagement.common.vo.scoringCity.ScoringPage;
import com.unis.app.service.BizRespScoringCityService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**粮食安全行政首长责任制-----评分结果录入(州市)---填报时间   BIZ_RESP_SCORING_CITY
 * @Auther:张新亮
 * @Date: 2019/9/19 0019 15:42
 * @Description:
 */
@RestController
@RequestMapping("/scoringCity")
@Slf4j
@Api(value = "粮食安全首长责任制---州市任务填报设置", tags = "粮食安全首长责任制--州市任务填报设置")
public class BizRespScoringCityController {
    @Autowired
    private BizRespScoringCityService bizRespScoringCityService;



    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody ScoringPage scoringPage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            ResponseWrapper responseWrapper= bizRespScoringCityService.findByPage(scoringPage, page, size);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }




    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringCityService.findById(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 根据id查询考核目标任务--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----根据年分查询明细", notes = "参数：id ")
    @GetMapping(value = "/findByYear/{year}")
    public ResponseWrapper findByYear(
            @PathVariable("year") String  year
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringCityService.findByYear(year);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }



    /**
     *  根据年分和状态---考核评分权重--对象
     * @return
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置----根据年分和状态---考核评分权重--对象", notes = "")
    @GetMapping(value = "/findByYearAndStatus/{year}/{status}")
    public ResponseWrapper findByYearAndStatus(
            @PathVariable("year") String  year,
            @PathVariable("status") String  status
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringCityService.findByYearAndStatus(year, status);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 更新--考核目标任务
     *
     * @param cityVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市任务填报设置---编辑", notes = "参数：taskVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody CityVO cityVO
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespScoringCityService.update(cityVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败"+ e.getMessage() ,null);
        }

    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全首长责任制--州市考核任务管理----发布", notes = "参数：")
    @GetMapping(value = "/publish/{id}")
    public ResponseWrapper publish(
            @PathVariable("id") String id
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringCityService.publish(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }

}