package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.scoringWeight.BizRespScoringWeightPageVO;
import com.unis.accountability.businessmanagement.common.vo.scoringWeight.WeightVO;
import com.unis.app.service.BizRespScoringWeightService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @Auther:张新亮
 * @Date: 2019/7/25 0025 16:38
 * @Description:
 */
@RestController
@Slf4j
@Api(value = "粮食安全行政首长责任制-----省级任务填报设置", tags = "粮食安全行政首长责任制：省级任务填报设置")
@RequestMapping("/scoringWeight")
public class BizRespScoringWeightController {
    @Autowired
    private BizRespScoringWeightService bizRespScoringWeightService;

    /**
     * 考核评分权重--考核等级设置
     * @return
     */
    @ApiOperation(value = "考核评分权重--考核等级设置", notes = " type  save  update")
    @GetMapping(value = "/findByWeightRank/{type}/{id}")
    public ResponseWrapper findByWeightRank(
            @PathVariable("type") String  type,
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringWeightService.findByWeightRank(type, id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 考核评分权重--查询可选年分
     * @return
     */
    @ApiOperation(value = "考核评分权重--查询可选年分", notes = "type: save 新增 page 分页查询  ")
    @GetMapping(value = "/findByYear/{type}")
    public ResponseWrapper findByYear(
            @PathVariable("type") String  type
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringWeightService.findByYear(type);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 考核评分权重--查询可选年分
     * @return
     */
    @ApiOperation(value = "考核评分权重--查询复制评分表可选年分", notes = "year: ")
    @GetMapping(value = "/findByCopyYear")
    public ResponseWrapper findByCopyYear(
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringWeightService.findByCopyYear();
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }




    /**
     *  根据年分和状态---考核评分权重--对象
     * @return
     */
    @ApiOperation(value = "根据年分和状态---考核评分权重--对象", notes = "")
    @GetMapping(value = "/findByYearAndStatus/{year}/{status}")
    public ResponseWrapper findByYearAndStatus(
            @PathVariable("year") Integer  year,
            @PathVariable("status") Integer  status
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringWeightService.findByYearAndStatus(year, status);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }



    /**
     * 保存数据---核评分权重
     * @param weightVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重----保存", notes = "参数：考核评分权重 scoringWeightVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody WeightVO weightVO
    ) {
        System.out.println("保存=====考核评分权重==="+weightVO.toString());
        try {
            ResponseWrapper responseWrapper= bizRespScoringWeightService.save(weightVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("考核评分权重，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }




    /**
     * 核评分权重----分页
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "核评分权重----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody BizRespScoringWeightPageVO pageVO,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespScoringWeightService.findByPage(pageVO, page, size);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("核评分权重分页模糊查询信息{}", e.getMessage());
            return ResponseWrapper.error(500, "核评分权重分页模糊查询信息失败",null);
        }
    }





    /**
     * 根据id查询考核内容--明细
     * @param id 计划id
     * @return
     */
    @ApiOperation(value = "核评分权重---查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper = bizRespScoringWeightService.findById(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }



    /**
     * 保存数据---核评分权重
     * @param weightVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重---修改", notes = "参数：考核评分权重 scoringWeightVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody WeightVO weightVO
    ) {
        System.out.println("保存=====考核评分权重==="+weightVO.toString());
        try {
            ResponseWrapper responseWrapper =bizRespScoringWeightService.update(weightVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("考核评分权重，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重---发布", notes = "参数：")
    @GetMapping(value = "/publish/{id}")
    public ResponseWrapper publish(
            @PathVariable("id") String  id
    ) {
        try {
            ResponseWrapper responseWrapper=bizRespScoringWeightService.publish(id);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }



    /**
     * 删除考核评分权重
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "核评分权重---删除", notes = "参数")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody String  id) {
        try {
            ResponseWrapper responseWrapper = bizRespScoringWeightService.deletes(id);
            return responseWrapper;
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败",null);
        }
    }



}