package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.msgNotice.UserDTO;
import com.unis.app.service.BizRespUserService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**省长首长责任制用户部门表
 * @Auther:张新亮
 * @Date: 2018/12/3 0003 11:10
 * @Description:
 */
@RestController
@RequestMapping("/respUser")
@Slf4j
@Api(value = "粮食安全省长责任制--省市单位和外部部门", tags = "粮食安全省长责任制--省市单位和外部部门")
public class BizRespUserController {
    @Autowired
    private BizRespUserService bizRespUserService;





    /**
     * 查询所有部门
     * 自评部门 指的是部门表 sys_department 下 type 为 部门 例如： select id,name,parent_id as parentId,parent_name as parentName,type from sys_department
     where parent_id=7416  and type='部门' and   name!='局领导' and IS_DELETED=0 order by orders asc
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全省长责任制--省市单位和外部部门 -----查询所有部门 code : 1 自评部门   0 : 牵头部门 、 配合部门", notes = "参数：考核内容 code")
    @PostMapping(value = "/findByDeptName/{code}")
    public ResponseWrapper findByDeptName(
            @PathVariable String code
    ) {
        try {
            List<Map> mapList =null;
            String areaCode= CurrentUtil.getAreaCode();
            //外部单位  0 : 牵头部门 、 配合部门
            if("0".equals(code)){
                mapList = bizRespUserService.findByQtbmAndPhbm(areaCode);
            }
//            //内设部门  自评部门
//            if("1".equals(code)){
//                mapList = bizRespUserService.findByZpbm(orgId);
//            }
            return ResponseWrapper.success(200, "查询成功",mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }

    @ApiOperation(value = "粮食安全省长责任制--省市单位和外部部门 -----查询所有部门 ", notes = "参数：考核内容 code")
    @PostMapping(value = "/findByDeptList/{code}/{areaCode}")
    public ResponseWrapper findByDeptList(
            @PathVariable("code") String code,
            @PathVariable("areaCode") String areaCode
    ) {
        try {
            List<Map> mapList =null;
            //外部单位  0 : 牵头部门 、 配合部门
            if("0".equals(code)){
                mapList = bizRespUserService.findByQtbmAndPhbm(areaCode);
            }
            return ResponseWrapper.success(200, "查询成功",mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    @ApiOperation(value = "粮食安全省长责任制------所有机构树 ", notes = "参数：考核内容 code")
    @PostMapping(value = "/findByOrgTree")
    public ResponseWrapper findByOrgTree(
    ) {
        try {
            List<Map> mapList =bizRespUserService.findByOrgTree();
            return ResponseWrapper.success(200, "查询成功",mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }




    @ApiOperation(value = "粮食安全省长责任制--获取所有省市", notes = "参数：考核内容 code")
    @GetMapping(value = "/findDataShiTree")
    public ResponseWrapper findDataShiTree(
    ) {
        try {
            List<Map> mapList=bizRespUserService.findDataShiTree();
            return ResponseWrapper.success(200, "查询成功",mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    @ApiOperation(value = "粮食安全省长责任制--获取所有省市--粮食产区和粮食非产区", notes = "参数：考核内容 code")
    @GetMapping(value = "/findNyqAndFnyq")
    public ResponseWrapper findNyqAndFnyq(
    ) {
        try {
            Map map=bizRespUserService.findNyqAndFnyq();
            return ResponseWrapper.success(200, "查询成功",map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    @ApiOperation(value = "粮食安全省长责任制--获取省市所有部门信息--非树", notes = "参数：考核内容 code")
    @GetMapping(value = "/findByAllDept")
    public ResponseWrapper findByAllDept(
    ) {
        try {
            List<Map> map=bizRespUserService.findByAllDept();
            return ResponseWrapper.success(200, "查询成功",map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    @ApiOperation(value = "粮食安全省长责任制--获取省市所有部门信息--树", notes = "参数：考核内容 code")
    @GetMapping(value = "/findByDeptTree")
    public ResponseWrapper findByDeptTree(
    ) {
        try {
            List<Map> map=bizRespUserService.findByDeptTree();
            return ResponseWrapper.success(200, "查询成功",map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    @ApiOperation(value = "粮食安全省长责任制--评分表分处室考核（市部门）--考核处室", notes = "参数：考核内容 code")
    @GetMapping(value = "/findByUserTree")
    public ResponseWrapper findByUserTree(
    ) {
        try {
            Set<Map> map=bizRespUserService.findByUserTree();
            return ResponseWrapper.success(200, "查询成功",map);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    @ApiOperation(value = "粮食安全省长责任制--省市单位和外部部门 -----组织机构树", notes = "参数：考核内容 code")
    @GetMapping(value = "/getAllOrgDescendantsTree")
    public ResponseWrapper getAllOrgDescendantsTree(
            @RequestParam String orgCode
    ) {
        try {
            List<Map> mapList =null;
            if(StringUtils.isEmpty(orgCode)){
                orgCode=CurrentUtil.getOrgId();
            }
            //外部单位  0 : 牵头部门 、 配合部门
            mapList = bizRespUserService.getAllOrgDescendantsTree(orgCode);
            return ResponseWrapper.success(200, "查询成功",mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }








    /**
     * 保存数据 考核内容
     *
     * @param UserDTO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----机构用户管理 市区----保存", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/saveOrg")
    public ResponseWrapper saveOrg(
            @RequestBody UserDTO UserDTO
    ) {
        System.out.println("保存=====机构用户管理 市区==="+UserDTO.toString());
        try {
            ResponseWrapper responseWrapper = bizRespUserService.saveOrg(UserDTO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 保存数据 考核内容
     *
     * @param UserDTO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----部门用户管理 市区----保存", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/saveDept")
    public ResponseWrapper saveDept(
            @RequestBody UserDTO UserDTO
    ) {
        System.out.println("保存=====部门用户管理 市区==="+UserDTO.toString());
        try {
            ResponseWrapper responseWrapper = bizRespUserService.saveDept(UserDTO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }




    /**
     * 保存数据 考核内容
     *
     * @param UserDTO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----机构用户管理 市区----根据orgCode查询orgName", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/orgNameByCode")
    public ResponseWrapper orgNameByCode(
            @RequestBody UserDTO UserDTO
    ) {
        System.out.println("保存=====机构用户管理 市区==="+UserDTO.toString());
        try {
            ResponseWrapper responseWrapper = bizRespUserService.orgNameByCode(UserDTO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    /**
     * 保存数据 考核内容
     *
     * @param UserDTO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----部门用户管理 市区----根据userCode查询userLoginName", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/findByUserCode")
    public ResponseWrapper findByUserCode(
            @RequestBody UserDTO UserDTO
    ) {
        System.out.println("保存=====用户管理 市区==="+UserDTO.toString());
        try {
            ResponseWrapper responseWrapper = bizRespUserService.findByUserCode(UserDTO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }



    /**
     * 保存数据 考核内容
     *
     * @param UserDTO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "粮食安全行政首长责任制----部门用户管理 市区----根据deptCode查询deptName", notes = "参数：考核内容 ContentVO")
    @PostMapping(value = "/findByDeptNameByCode")
    public ResponseWrapper findByDeptNameByCode(
            @RequestBody UserDTO UserDTO
    ) {
        System.out.println("保存=====部门用户管理 市区==="+UserDTO.toString());
        try {
            ResponseWrapper responseWrapper = bizRespUserService.findByDeptNameByCode(UserDTO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }









}