package com.unis.app.controller;

import com.unis.accountability.businessmanagement.common.vo.msgNotice.MsgNoticePage;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.MsgNoticePublishVO;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.MsgNoticeVO;
import com.unis.app.service.MsgNoticeService;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * @Auther:张新亮
 * @Date: 2019/11/5 0005 14:21
 * @Description:
 */
@RestController
@RequestMapping("/msgNotice")
@Slf4j
@Api(value = "信息报送--信息报送", tags = "信息报送--信息报送")
public class MsgNoticeController {

    @Autowired
    private MsgNoticeService msgNoticeService;



    /**
     * 保存数据 信息报送
     *
     * @param msgNoticeVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送----保存", notes = "参数：考核内容 msgNoticeVO")
    @PostMapping(value = "/save")
    public ResponseWrapper save(
            @RequestBody MsgNoticeVO msgNoticeVO
    ) {
        System.out.println("保存=====信息报送==="+msgNoticeVO.toString());
        try {
            ResponseWrapper responseWrapper = msgNoticeService.save(msgNoticeVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送---采用", notes = "参数：")
    @PostMapping(value = "/publish")
    public ResponseWrapper publish(
            @RequestBody MsgNoticePublishVO msgNoticePublishVO
    ) {
        try {
            ResponseWrapper responseWrapper= msgNoticeService.publish(msgNoticePublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败" ,null);
        }
    }


    /**
     * 发布
     * @param
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送---批量采用", notes = "参数：")
    @PostMapping(value = "/publishALL")
    public ResponseWrapper publishALL(
            @RequestBody MsgNoticePublishVO msgNoticePublishVO
    ) {
        try {
            ResponseWrapper responseWrapper=  msgNoticeService.publishALL(msgNoticePublishVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error( "更新对象，发生异常", e.getMessage() );
            return ResponseWrapper.error( 500, "操作失败",null );
        }
    }



    /**
     *信息报送----查看
     * @return
     */
    @ApiOperation(value = "信息报送----查看", notes = "参数：id ")
    @GetMapping(value = "/findById/{id}")
    public ResponseWrapper findById(
            @PathVariable("id") String id
    ) {
        try {
            MsgNoticeVO msgNoticeVO=msgNoticeService.findById(id);
            return ResponseWrapper.success(200, "查询成功", msgNoticeVO);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     *信息报送----查看   10  未提交  20  已提交 30  未采用 40 已采用
     * @return
     */
    @ApiOperation(value = "信息报送----状态", notes = "参数：id ")
    @GetMapping(value = "/findByStatus")
    public ResponseWrapper findById(
    ) {
        try {
            List<Map> mapList=new ArrayList();
            Map map=new HashMap();
            map.put("name","未提交");
            map.put("status","10");
            mapList.add(map);
            map=new HashMap();
            map.put("name","已提交");
            map.put("status","20");
            mapList.add(map);
            map=new HashMap();
            map.put("name","未采用");
            map.put("status","30");
            mapList.add(map);
            map=new HashMap();
            map.put("name","已采用");
            map.put("status","40");
            mapList.add(map);
            return ResponseWrapper.success(200, "查询成功", mapList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error("查找对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "单位信息查询失败",null);
        }
    }


    /**
     * 分页查询
     * @param
     * @param size
     * @return
     */
    @ApiOperation(value = "信息报送----分页", notes = "参数：内容")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true)
    })
    @PostMapping(value = "/findByPage/{page}/{size}")
    public ResponseWrapper findByPage(
            @RequestBody MsgNoticePage msgNoticePage,
            @PathVariable("page") Integer page,
            @PathVariable("size") Integer size
    ) {
        try {
            Map result = msgNoticeService.findByPage(msgNoticePage, page, size);
            if (ObjectUtils.notEqual(result, null)) {
                return ResponseWrapper.success(200, "查询成功", result);
            }
            return ResponseWrapper.error();
        } catch (Exception e) {
            e.printStackTrace();
            log.error("活动分页查询失败{}", e.getMessage());
            return ResponseWrapper.error(500, "活动信息查询失败",null);
        }
    }



    /**
     * 保存数据 信息报送
     *
     * @param msgNoticeVO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送----修改", notes = "参数：信息报送 msgNoticeVO")
    @PostMapping(value = "/update")
    public ResponseWrapper update(
            @RequestBody MsgNoticeVO msgNoticeVO
    ) {
        System.out.println("保存=====信息报送==="+msgNoticeVO.toString());
        try {
            ResponseWrapper responseWrapper = msgNoticeService.update(msgNoticeVO);
            return responseWrapper;
        } catch (Exception e) {
            e.printStackTrace();
            log.error("保存执法人员详情，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "保存失败",null);
        }
    }


    /**
     * 删除考核评分权重
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "信息报送---删除", notes = "参数")
    @DeleteMapping(value = "/deletes")
    public ResponseWrapper deletes(@RequestBody String[] ids) {
        try {
            ResponseWrapper responseWrapper = msgNoticeService.deletes(ids);
            return responseWrapper;
        } catch (Exception e) {
            log.error("删除对象，发生异常", e.getMessage());
            return ResponseWrapper.error(500, "用户信息删除失败",null);
        }
    }






}