package com.unis.app.controller;

import com.unis.accountability.businessmanagement.client.ProvinceLeadDeptClient;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskQueryVO;
import com.unis.accountability.businessmanagement.common.vo.opinion.BizRespDepartmentalOpinionVO;
import com.unis.app.service.ProvinceLeadDeptService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

/**
 * @Auther:邹杰利
 * @Date: 2019/9/20
 * @Description:省级牵头部门
 */
@RestController
@Slf4j
@Api(value = "盟市长责任制--省级牵头部门", tags = "盟市长责任制--省级牵头部门")
public class ProvinceLeadDeptController {

    @Autowired
    private ProvinceLeadDeptClient deptClient;
    @Autowired
    private ProvinceLeadDeptService provinceLeadDeptService;

    /**
     * @author 邹杰利
     * @param bigTaskQueryVO
     * @param pageNum
     * @param pageSize
     * @return
     */
    @ApiOperation(value = "盟市长责任制--省级牵头部门--条件分页查询", notes = "参数：")
    @PostMapping(value = "/provinceLeadDept/{pageNum}/{pageSize}")
    public ResponseWrapper getProvinceLeadDept(@RequestBody BigTaskQueryVO bigTaskQueryVO,
                                               @PathVariable("pageNum") Integer pageNum,
                                               @PathVariable("pageSize") Integer pageSize){
        bigTaskQueryVO.setDeptId(CurrentUtil.getDeptId());
        return provinceLeadDeptService.getProvinceLeadDept(bigTaskQueryVO,pageNum,pageSize);
    }

    @ApiOperation(value = "盟市长责任制--省级牵头部门--根据任务id查询详情", notes = "参数：id")
    @GetMapping(value = "/provinceLeadDept/{id}/{areaCode}/{coordinateDeptId}")
    public ResponseWrapper getProvinceLeadDeptDetail(@PathVariable("id") String id,
                                                     @PathVariable("areaCode") String areaCode,
                                                     @PathVariable("coordinateDeptId") String coordinateDeptId){
        return provinceLeadDeptService.getProvinceLeadDeptDetail(id,areaCode,coordinateDeptId);
    }


    @ApiOperation(value = "盟市长责任制--省级牵头部门--更新省级牵头部门评分", notes = "参数：BizRespDepartmentalOpinionVO")
    @PutMapping(value = "/provinceBizRespDepartmentalOpinion")
    public ResponseWrapper updateProvinceBizRespDepartmentalOpinion(@RequestBody BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO){
        bizRespDepartmentalOpinionVO.setUpdateBy(CurrentUtil.getUserName());
        bizRespDepartmentalOpinionVO.setUpdateTime(new Date());
        return deptClient.updateBizRespDepartmentalOpinion(bizRespDepartmentalOpinionVO);
    }


//    @ApiOperation(value = "盟市长责任制--省级牵头部门--新增省级牵头部门复评分", notes = "参数：BizRespDepartmentalOpinionVO")
//    @PostMapping(value = "/provinceLeadOpinion")
//    public ResponseWrapper insertProvinceLeadOpinion(@RequestBody BizRespDepartmentalOpinionVO bizRespDepartmentalOpinionVO){
//        bizRespDepartmentalOpinionVO.setCreateBy(CurrentUtil.getUserName());
//        bizRespDepartmentalOpinionVO.setCreateTime(new Date());
//        return deptClient.insertProvinceLeadOpinion(bizRespDepartmentalOpinionVO);
//    }


    @ApiOperation(value = "盟市长责任制--省级牵头/配合部门--批量上报", notes = "参数：taskIds")
    @PutMapping(value = "/provinceLeadOpinion/{year}/{type}")
    public ResponseWrapper updateTaskStatus(@PathVariable(value = "year") Integer year,
                                            @PathVariable(value = "type") String type){
        String updateBy = CurrentUtil.getOrgName();
        return deptClient.updateTaskStatus(year,type,updateBy);
    }



}