package com.unis.app.service.Impl;

import com.alibaba.fastjson.JSON;
import com.unis.accountability.businessmanagement.client.BizRespCityPhbmClient;
import com.unis.accountability.businessmanagement.common.vo.FileVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPage;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.CityPhbmPageVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.cityPhbm.PhbmVO;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.CityTaskVO;
import com.unis.accountability.businessmanagement.common.vo.cityZpbm.CityZpbmPublishVO;
import com.unis.app.service.BizRespCityPhbmService;
import com.unis.app.service.BizRespCityZpbmService;
import com.unis.app.service.BizRespFileService;
import com.unis.app.service.BizRespUserService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/9/21 0021 16:09
 * @Description:
 */
@Service
public class BizRespCityPhbmServiceImpl implements BizRespCityPhbmService {
    @Autowired
    private BizRespCityPhbmClient bizRespCityPhbmClient;
    @Autowired
    private BizRespUserService bizRespUserService;
    @Autowired
    private BizRespCityZpbmService bizRespCityZpbmService;
    @Autowired
    private BizRespFileService bizRespFileService;

    /**
     * 粮食安全行政首长责任制----市级配合部门----分页
     * @param cityPhbmPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public Map findByPage(CityPhbmPage cityPhbmPage, Integer page, Integer size) {
       // cityPhbmPage.setDeptId(CurrentUtil.getOrgId());
        if(CurrentUtil.getDeptId().length()==5){
            System.out.println("=========================使用 orgId 查询数据=========================");
            cityPhbmPage.setDeptId(CurrentUtil.getOrgId());
        }else{
            System.out.println("=========================使用 userCode 查询数据=========================");
            cityPhbmPage.setDeptId(CurrentUtil.getOrgId());
            cityPhbmPage.setUserCode(CurrentUtil.getUserId());
        }
        ResponseWrapper responseWrapper=bizRespCityPhbmClient.findByPage(cityPhbmPage,page,size);
        String dataJson= (String) responseWrapper.getData();
        Map map= JSON.parseObject(dataJson, Map.class);
        if(map!=null){
            String listJson=JSON.toJSONString(map.get("list"));
            List<CityPhbmPageVO> mapList= JSON.parseArray(listJson, CityPhbmPageVO.class);
            for(CityPhbmPageVO pageVO:mapList){
                String phbm=bizRespUserService.findByPhbmName(pageVO.getPhbm(),CurrentUtil.getAreaCode());
                pageVO.setPhbm(phbm);
            }
            map.put("list", mapList);
        }
        return map;
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门----查看
     * @param id
     * @return
     */
    @Override
    public CityTaskVO findById(String id) {
        String deptId=CurrentUtil.getOrgId();
        CityTaskVO cityTaskVO=bizRespCityZpbmService.findById(id);
        ResponseWrapper responseWrapper=bizRespCityPhbmClient.findById(id, deptId);
        String dataJson= (String) responseWrapper.getData();
        PhbmVO phbmVO= JSON.parseObject(dataJson, PhbmVO.class);
        String phbm=bizRespUserService.findByPhbmName(phbmVO.getPhbm(), phbmVO.getAreaCode());

        if(StringUtils.isNotEmpty(phbmVO.getFileId())){
            //上传文件的信息
            List<FileVO> fileVOList=bizRespFileService.getFileInfo(phbmVO.getFileId());
            String fileName=fileVOList.get(0).getFileName();
            phbmVO.setFileName(fileName);
        }

        phbmVO.setPhbm(phbm);
        cityTaskVO.setPhbmVO(phbmVO);
        return cityTaskVO;
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---编辑
     * @param phbmVO
     * @return
     */
    @Override
    public ResponseWrapper update(PhbmVO phbmVO) {
        PhbmUpdateVO phbmUpdateVO=new PhbmUpdateVO();
        phbmUpdateVO.setPhbmVO(phbmVO);
        phbmUpdateVO.setUpdateBy(CurrentUtil.getUserName());
        return  bizRespCityPhbmClient.update(phbmUpdateVO);
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---发布
     * @param id
     * @return
     */
    @Override
    public ResponseWrapper publish(String id) {
        CityZpbmPublishVO cityZpbmPublishVO=new CityZpbmPublishVO();
        cityZpbmPublishVO.setId(id);
        cityZpbmPublishVO.setDeptId(CurrentUtil.getOrgId());
        cityZpbmPublishVO.setUpdateBy(CurrentUtil.getUserName());
        return  bizRespCityPhbmClient.publish(cityZpbmPublishVO);
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---批量发布
     * @return
     */
    @Override
    public ResponseWrapper publishALL(CityZpbmPublishVO cityZpbmPublishVO) {
        cityZpbmPublishVO.setDeptId(CurrentUtil.getOrgId());
        cityZpbmPublishVO.setUpdateBy(CurrentUtil.getUserName());
        return  bizRespCityPhbmClient.publishALL(cityZpbmPublishVO);
    }


    /**
     * 粮食安全行政首长责任制----市级配合部门---提交比例
     * @param year
     * @return
     */
    @Override
    public Map findByTaskDistributionRatio(String year) {
        Map result=new HashMap();
        CityPhbmPage cityPhbmPage=new CityPhbmPage();
        cityPhbmPage.setDeptId(CurrentUtil.getOrgId());
        cityPhbmPage.setYear(year);
        //总数
        List<CityPhbmPageVO> totalNumber= fidByYearAndDeptIdAndStatus(cityPhbmPage);
        result.put("totalNumber", totalNumber.size());
        //未录入
        cityPhbmPage.setStatus("10");
        List<CityPhbmPageVO> wlr= fidByYearAndDeptIdAndStatus(cityPhbmPage);
        result.put("wlr",wlr.size());
        //已录入
        cityPhbmPage.setStatus("20");
        List<CityPhbmPageVO> ylr= fidByYearAndDeptIdAndStatus(cityPhbmPage);
        result.put("ylr",ylr.size());
        //已提交
        cityPhbmPage.setStatus("30");
        List<CityPhbmPageVO> ytj= fidByYearAndDeptIdAndStatus(cityPhbmPage);
        result.put("ytj",ytj.size());
        return result;
    }

    /**
     * 粮食安全行政首长责任制----市级配合部门---根据年份部门状态查询明细
     * @param cityPhbmPage
     * @return
     */
    @Override
    public List<CityPhbmPageVO> fidByYearAndDeptIdAndStatus(CityPhbmPage cityPhbmPage) {
        ResponseWrapper responseWrapper= bizRespCityPhbmClient.fidByYearAndDeptIdAndStatus(cityPhbmPage);
        String dataJson= (String) responseWrapper.getData();
        List<CityPhbmPageVO> cityZpbmPageVOList= JSON.parseArray(dataJson, CityPhbmPageVO.class);
        return cityZpbmPageVOList;
    }
}