package com.unis.app.service.Impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.unis.accountability.businessmanagement.client.BizRespCityTaskDistributionClient;
import com.unis.accountability.businessmanagement.common.vo.backlog.ReceiverCollectionVO;
import com.unis.accountability.businessmanagement.common.vo.cityTaskDistribution.*;
import com.unis.accountability.businessmanagement.common.vo.respScoreInput.BizRespScoreInputVO;
import com.unis.app.config.MyUserClient;
import com.unis.app.service.BizRespCityTaskDistributionService;
import com.unis.app.service.BizRespScoreInputService;
import com.unis.app.service.BizRespUserService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.collections.map.HashedMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/9/20 0020 15:22
 * @Description:
 */
@Service
public class BizRespCityTaskDistributionServiceImpl implements BizRespCityTaskDistributionService {
    @Autowired
    private BizRespCityTaskDistributionClient bizRespCityTaskDistributionClient;
    @Autowired
    private BizRespUserService bizRespUserService;
    @Autowired
    private BizRespScoreInputService bizRespScoreInputService;
    @Autowired
    private MyUserClient myUserClient;

    /**
     * 粮食安全行政首长责任制----州市任务分配管理----分页
     * @param cityTaskPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public Map findByPage(CityTaskPage cityTaskPage, Integer page, Integer size) {
        cityTaskPage.setAreaCode(CurrentUtil.getAreaCode());
        String areaCodeType=bizRespUserService.getAreaCodeType(CurrentUtil.getAreaCode());
        cityTaskPage.setAreaCodeType(areaCodeType);
        ResponseWrapper responseWrapper=bizRespCityTaskDistributionClient.findByPage(cityTaskPage,page,size);
        String dataJson= (String) responseWrapper.getData();
        Map map=JSON.parseObject(dataJson, Map.class);
        String listJson=JSON.toJSONString(map.get("list"));
        List<CityTaskDistributionPageVO> mapList= JSON.parseArray(listJson, CityTaskDistributionPageVO.class);
        for(CityTaskDistributionPageVO pageVO:mapList){
            String phbm=bizRespUserService.findByPhbmName(pageVO.getPhbm(),CurrentUtil.getAreaCode());
            pageVO.setPhbm(phbm);
            String qtbm=bizRespUserService.findByQtbmName(pageVO.getQtbm(),CurrentUtil.getAreaCode());
            pageVO.setQtbm(qtbm);
        }
        map.put("list",mapList);
        return map;
    }

    /**
     * 粮食安全行政首长责任制----州市任务分配管理----查看
     * @param id
     * @return
     */
    @Override
    public CityTaskDistributionVO findById(String id) {
        ResponseWrapper responseWrapper=bizRespCityTaskDistributionClient.findById(id);
        String dataJson= (String) responseWrapper.getData();
        CityTaskDistributionVO cityTaskDistributionVO= JSON.parseObject(dataJson, CityTaskDistributionVO.class);
        if(cityTaskDistributionVO!=null){
            String cityPhbm=bizRespUserService.findByPhbmName(cityTaskDistributionVO.getCityPhbm(),cityTaskDistributionVO.getCityAreacode());
            cityTaskDistributionVO.setCityPhbm(cityPhbm);
            String cityQtbm=bizRespUserService.findByQtbmName(cityTaskDistributionVO.getCityQtbm(),cityTaskDistributionVO.getCityAreacode());
            cityTaskDistributionVO.setCityQtbm(cityQtbm);
        }
        return cityTaskDistributionVO;
    }

    /**
     * 粮食安全行政首长责任制----州市任务分配管理---编辑
     * @param cityTaskDistributionVO
     * @return
     */
    @Override
    public ResponseWrapper update(CityTaskDistributionVO cityTaskDistributionVO) {
        CityTaskUpdateVO  cityTaskUpdateVO=new CityTaskUpdateVO();
        cityTaskUpdateVO.setUpdateBy(CurrentUtil.getUserName());
        cityTaskUpdateVO.setCityTaskDistributionVO(cityTaskDistributionVO);
        cityTaskUpdateVO.setOrgId(CurrentUtil.getOrgId());
        cityTaskUpdateVO.setDeptId(CurrentUtil.getDeptId());
        return bizRespCityTaskDistributionClient.update(cityTaskUpdateVO);
    }

    /**
     * 粮食安全行政首长责任制----州市任务分配管理---发布
     * @param id
     */
    @Override
    public ResponseWrapper publish(String id) {
        CityTaskPublishVO cityTaskPublishVO=new CityTaskPublishVO();
        cityTaskPublishVO.setId(id);
        cityTaskPublishVO.setUpdateBy(CurrentUtil.getUserName());
        cityTaskPublishVO.setAreaCode(CurrentUtil.getAreaCode());
        return  bizRespCityTaskDistributionClient.publish(cityTaskPublishVO);
    }

    /**
     * 粮食安全行政首长责任制----州市任务分配管理---批量发布
     * @param
     */
    @Override
    public ResponseWrapper publishALL(CityTaskPublishVO cityTaskPublishVO) {
        cityTaskPublishVO.setAreaCode(CurrentUtil.getAreaCode());
        cityTaskPublishVO.setStatus("1");
        cityTaskPublishVO.setUpdateBy(CurrentUtil.getUserName());
        return bizRespCityTaskDistributionClient.publishALL(cityTaskPublishVO);
    }

    /**
     * 粮食安全行政首长责任制----州市任务分配管理---分配比例
     * @return
     */
    @Override
    public Map findByTaskDistributionRatio(String  year) {
        CityTaskPublishVO cityTaskPublishVO=new CityTaskPublishVO();
        Map result=new HashMap();
        cityTaskPublishVO.setAreaCode(CurrentUtil.getAreaCode());
        cityTaskPublishVO.setYear(year);
        List<BizRespScoreInputVO> totalNumber= bizRespScoreInputService.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
        result.put("totalNumber", totalNumber.size());
        //未分配
        cityTaskPublishVO.setStatus("0");
        List<BizRespScoreInputVO> wfp= bizRespScoreInputService.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
        result.put("wfp",wfp.size());
        //已分配
        cityTaskPublishVO.setStatus("1");
        List<BizRespScoreInputVO> yfp= bizRespScoreInputService.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
        result.put("yfp",yfp.size());
        //已发布
        cityTaskPublishVO.setStatus("2");
        List<BizRespScoreInputVO> yfb= bizRespScoreInputService.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
        result.put("yfb",yfb.size());
        //上报省级
        cityTaskPublishVO.setStatus("3");
        List<BizRespScoreInputVO> sbsj= bizRespScoreInputService.findByYearAndStatusAndAreaCode(cityTaskPublishVO);
        result.put("sbsj",sbsj.size());
        return result;
    }



    /**
     * 粮食安全行政首长责任制----州市任务分配管理----分页
     * @param cityTaskPage
     * @param page
     * @param size
     * @return
     */
    @Override
    public Map findZpCityByPage(CityTaskPage cityTaskPage, Integer page, Integer size) {
        ResponseWrapper responseWrapper=bizRespCityTaskDistributionClient.findZpCityByPage(cityTaskPage, page, size);
        String dataJson= (String) responseWrapper.getData();
        Map map=JSON.parseObject(dataJson, Map.class);
        String listJson=JSON.toJSONString(map.get("list"));
        List<Map> mapList= JSON.parseArray(listJson, Map.class);
        List<Map> mapList1 = new ArrayList<>();
        for(Map pageVO:mapList){
            String areaCode=pageVO.get("areacode").toString();
            pageVO.put("areaCode", areaCode);
            String areaCodeType=bizRespUserService.getAreaCodeType(areaCode);
            pageVO.put("areaCodeType", areaCodeType);
            List<String> shiAreaCode=new ArrayList();
            shiAreaCode.add(areaCode);
            String areaCodeName=bizRespUserService.getCity(shiAreaCode);
            pageVO.put("areaCodeName", areaCodeName);
            if(null != cityTaskPage.getAreaCodeType() && !"".equals(cityTaskPage.getAreaCodeType())){
                if (pageVO.get("areaCodeType").equals(cityTaskPage.getAreaCodeType())){
                    mapList1.add(pageVO);
                }
            }else {
                mapList1 = mapList;
            }
        }
        map.put("list",mapList1);
        return map;
    }

    /**
     * 粮食安全行政首长责任制----区自评查看（市局）---考核分发
     * @param cityTaskPublishVO
     * @return
     */
    @Override
    public ResponseWrapper publishKhff(CityTaskPublishVO cityTaskPublishVO) {
        cityTaskPublishVO.setUserName(CurrentUtil.getUserName());
        cityTaskPublishVO.setUserId(CurrentUtil.getUserId());
        cityTaskPublishVO.setOrgName(CurrentUtil.getOrgName());
        cityTaskPublishVO.setStatus("3");
        List<ReceiverCollectionVO> userList = new ArrayList<>();
        //获取区粮办所有人
        List<Map> mapList=bizRespUserService.findDataShiTree();
        if(CollectionUtils.isEmpty(mapList)) {
            return ResponseWrapper.error( 500, "获取区粮办信息失败！" ,null);
        }
        List<String> areaCodeList=new ArrayList();
        Map<String,List<ReceiverCollectionVO>> mapUser = new HashedMap();
        for(Map map:mapList){
            String areaCode=map.get("areaCode").toString();
            mapUser.put(areaCode,new ArrayList<ReceiverCollectionVO>());
            areaCodeList.add(areaCode);
        }
        //市考核--cbl
        ResponseWrapper wrapper = myUserClient.findUserByAreaCode(areaCodeList);
        if (wrapper.isSuccess() && !ObjectUtils.isEmpty(wrapper.getData())) {
            JSONArray objArr = JSON.parseArray(JsonUtils.serialize(wrapper.getData()));
            if (!ObjectUtils.isEmpty(objArr)) {
                objArr.forEach(jsonObj -> {
                    JSONObject obj = (JSONObject) jsonObj;
                    ReceiverCollectionVO receiverCollectionVO = new ReceiverCollectionVO();
                    receiverCollectionVO.setUserId(obj.getString("userCode"));
                    receiverCollectionVO.setUserName(obj.getString("userName"));
                    receiverCollectionVO.setAreaCode(obj.getString("countyCode"));
                    userList.add(receiverCollectionVO);
                });
            }
        }
        mapUser = listToMap(mapUser,userList);
        cityTaskPublishVO.setUserList(mapUser);
        return bizRespCityTaskDistributionClient.publishKhff(cityTaskPublishVO);
    }
    public Map<String,List<ReceiverCollectionVO>> listToMap(Map<String,List<ReceiverCollectionVO>> map, List<ReceiverCollectionVO> userList){

        for(ReceiverCollectionVO receiverCollectionVO:userList){
            if(map.get(receiverCollectionVO.getAreaCode())!=null){
                map.get(receiverCollectionVO.getAreaCode()).add(receiverCollectionVO);
            }
        }
        return map;
    }

    /**
     * 粮食安全行政首长责任制----区自评查看（市局）---是否考核分发
     * @param cityTaskPublishVO
     * @return
     */
    @Override
    public ResponseWrapper findByIsKhff(CityTaskPublishVO cityTaskPublishVO) {
        return bizRespCityTaskDistributionClient.findByIsKhff(cityTaskPublishVO);
    }


}