package com.unis.app.service.Impl;

import com.alibaba.fastjson.JSON;
import com.unis.accountability.businessmanagement.client.BizRespExaminationTaskClient;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.*;
import com.unis.app.service.BizRespExaminationTaskService;
import com.unis.app.service.BizRespUserService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 17:49
 * @Description:
 */
@Service
public class BizRespExaminationTaskServiceImpl implements BizRespExaminationTaskService {
    @Autowired
    private BizRespExaminationTaskClient bizRespExaminationTaskClient;
    @Autowired
    private BizRespUserService bizRespUserService;

    /**
     * 粮食安全省长责任制--考核目标任务---查询可填分数
     * @param quotaId
     * @param responsibilityId
     * @return
     */
    @Override
    public ResponseWrapper findBySorce(String quotaId, String responsibilityId) {
        String deptId= CurrentUtil.getOrgId();
        return bizRespExaminationTaskClient.findBySorce(quotaId,responsibilityId,deptId);
    }

    /**
     * 粮食安全省长责任制--考核目标任务---保存
     * @param taskVO
     * @return
     */
    @Override
    public ResponseWrapper save(TaskVO taskVO) {
        TaskSaveVO taskSaveVO=new TaskSaveVO();
        taskSaveVO.setCreateBy(CurrentUtil.getUserName());
        taskSaveVO.setAreaCode(CurrentUtil.getAreaCode());
        taskSaveVO.setDeptId(CurrentUtil.getDeptId());
        taskSaveVO.setOrgId(CurrentUtil.getOrgId());
        taskSaveVO.setTaskVO(taskVO);
        return bizRespExaminationTaskClient.save(taskSaveVO);
    }


    /**
     * 粮食安全省长责任制--考核目标任务---分页
     * @param taskVO
     * @param page
     * @param size
     * @return
     */
    @Override
    public Map findByPage(TaskPageVO taskVO, Integer page, Integer size) {
        taskVO.setAreaCode(CurrentUtil.getAreaCode());
        ResponseWrapper responseWrapper=bizRespExaminationTaskClient.findByPage(taskVO, page, size);
        String dataJson= (String) responseWrapper.getData();
        Map map= JSON.parseObject(dataJson, Map.class);
        if(map!=null){
            String listJson=JSON.toJSONString(map.get("list"));
            List<Map> mapList= JSON.parseArray(listJson, Map.class);
            for(Map result:mapList){
                String qtbm=result.get("qtbm")==null?null:result.get("qtbm").toString();
                String phbm=result.get("phbm")==null?null:result.get("phbm").toString();
                if(StringUtils.isNotEmpty(phbm)){
                     phbm=bizRespUserService.findByPhbmName(phbm,CurrentUtil.getAreaCode());
                }
                if(StringUtils.isNotEmpty(qtbm)){
                    qtbm=bizRespUserService.findByQtbmName(qtbm, CurrentUtil.getAreaCode());
                }
                result.put("phbm",phbm);
                result.put("qtbm",qtbm);
            }
            map.put("list", mapList);
        }
       return map;
    }


    /**
     * 粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细
     * @param id
     * @return
     */
    @Override
    public ResponseWrapper findById(String id) {
        return bizRespExaminationTaskClient.findById(id);

    }

    /**
     * 粮食安全省长责任制--考核目标任务---编辑
     * @param taskVO
     * @return
     */
    @Override
    public ResponseWrapper update(TaskVO taskVO) {
        TaskUpdateVO taskUpdateVO=new TaskUpdateVO();
        taskUpdateVO.setUpdateBy(CurrentUtil.getUserName());
        taskUpdateVO.setTaskVO(taskVO);
        return bizRespExaminationTaskClient.update(taskUpdateVO);
    }
    @Override
    public ResponseWrapper updateOpinion(TaskVO taskVO) {
        TaskUpdateVO taskUpdateVO=new TaskUpdateVO();
        taskUpdateVO.setUpdateBy(CurrentUtil.getUserName());
        taskUpdateVO.setTaskVO(taskVO);
        return bizRespExaminationTaskClient.updateOpinion(taskUpdateVO);
    }
    /**
     * 粮食安全省长责任制--考核目标任务---批量删除
     * @param ids
     * @return
     */
    @Override
    public ResponseWrapper deletes(String[] ids) {
        DeleteVO deleteVO=new DeleteVO();
        deleteVO.setIds(ids);
        deleteVO.setDeleteBy(CurrentUtil.getUserName());
        return bizRespExaminationTaskClient.deletes(deleteVO);
    }

    /**
     * 粮食安全省长责任制--考核目标任务---根据id查询考核目标任务--明细--省市--牵头部门配合部门部门和自评部门专用
     * @param id
     * @return
     */
    @Override
    public TaskInfoVO  findByTaskInfo(String id) {
        ResponseWrapper responseWrapper=bizRespExaminationTaskClient.findByTaskInfo(id);
        String dataJson= (String) responseWrapper.getData();
        TaskInfoVO taskInfoVO= JSON.parseObject(dataJson, TaskInfoVO.class);
        return taskInfoVO;
    }
}