package com.unis.app.service.Impl;

import com.github.pagehelper.util.StringUtil;
import com.unis.accountability.businessmanagement.common.vo.FileVO;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.MsgNoticeVO;
import com.unis.app.config.FileClient;
import com.unis.app.service.BizRespFileService;
import com.unis.app.service.MsgNoticeService;
import com.unis.common.utils.ResponseWrapper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * @Auther:张新亮
 * @Date: 2019/9/21 0021 11:30
 * @Description:
 */
@Service
public class BizRespFileServiceImpl implements BizRespFileService {
    @Autowired
    private FileClient fileClient;
    @Value("${filesPath}")
    private String filesPath;
    @Autowired
    private MsgNoticeService msgNoticeService;




    /**
     * 获取自评部门上传文件的信息
     * @param fileId
     * @return
     */
    @Override
    public List<FileVO> getFileInfo(String fileId) {
        List<FileVO> fileVOList=new ArrayList();
        if(StringUtil.isNotEmpty(fileId)){
            String[] fileList=fileId.split(",");
            for(String fileIds:fileList){
                ResponseWrapper responseWrapper=fileClient.findById(fileIds);
                if(responseWrapper.getInfoCode()==200){
                    FileVO fileVO=new FileVO();
                    Map map= (Map) responseWrapper.getData();
                    fileVO.setFileId(fileIds);
                    fileVO.setFileName(map.get("name").toString());
                    System.out.println(map);
                    fileVOList.add(fileVO);
                }
            }
            return fileVOList;
        }
        return null;
    }


    /**
     * 信息报送-------文件下载
     * @param response
     * @param id
     * @param status
     */
    /**
     * 信息报送-------文件下载
     * @param response
     * @param id
     * @param status
     */
    @Override
    public void downloadMsgNotice(HttpServletResponse response, String id) {
        // filesPath
        String folder=System.getProperty("java.io.tmpdir");
        String pathUrl = folder + File.separatorChar;
        String time = String.valueOf(System.currentTimeMillis()) + File.separatorChar;
        String sourceFilePath = pathUrl + time;
        File file = new File(sourceFilePath);
        if (!file.exists()) {
            file.mkdirs();
        }
        MsgNoticeVO msgNoticeVO= msgNoticeService.findByInfo(id);
        //下载文件封装集合
        String fileId= StringUtils.join(msgNoticeVO.getFileId(), ",");
        List<FileVO> fileVOList= this.getFileInfo(fileId);

        File zipFile = new File(sourceFilePath + "/" + msgNoticeVO.getTitle());
        if (!zipFile.exists()) {
            zipFile.mkdirs();
        }
        for(FileVO fileVO:fileVOList){
            String path = zipFile.getPath()+ File.separatorChar;
            try {
                File fi = fileClient.download(Long.valueOf(fileVO.getFileId()));
                savePic(fi, path,fileVO.getFileName());
            } catch (Exception e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
        }

        try {
            zipCompress(zipFile.getPath() + ".zip", zipFile);
            downLoadZipFile(response, zipFile.getPath() + ".zip", msgNoticeVO.getTitle()+".zip");
            // 删除指定文件夹
            delFolder(sourceFilePath);
            System.out.println("文件夹创建成功");
        } catch (IOException e) {
            e.printStackTrace();
        }

    }






    /**
     * @Description: file 文件保存到本地
     * @date 2019年6月11日,下午5:45:10
     * @author huangshuai
     * @version v1.0
     *
     * @param file
     * @param filePath
     * @param fileName
     * @return
     */
    public File savePic(File file, String filePath, String fileName) {
        InputStream inputStream = null;
        OutputStream os = null;
        try {

            byte[] bs = new byte[1024 * 1024 * 5];// 1k * 1024 * 5
            int len;
            inputStream = new FileInputStream(file);
            os = new FileOutputStream(filePath + File.separator + fileName);
            while ((len = inputStream.read(bs)) != -1) {
                os.write(bs, 0, len);
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                os.close();
                inputStream.close();
            } catch (IOException e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
        }
        File sendFile = new File(filePath + File.separator + file.getName());
        return sendFile;
    }







    /**
     * @Description: TODO
     * @date 2019年6月4日,上午10:52:24
     * @author huangshuai
     * @version v1.0
     * @param zipSavePath 压缩好的zip包存放路径
     * @param sourceFile 
     *              待压缩的文件（单个文件或者整个文件目录）
     * @return
     * @throws IOException
     */
    public void zipCompress(String zipSavePath, File sourceFile) throws IOException {

        try {
            // 创建zip输出流
            ZipOutputStream zos = new ZipOutputStream(new FileOutputStream(zipSavePath));
            compress(zos, sourceFile, sourceFile.getName());
            zos.close();
        } catch (Exception e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
    }




    /**
     * @Description: 创建压缩包
     * @date 2019年6月11日,下午5:45:45
     * @author huangshuai
     * @version v1.0
     * @param zos
     * @param sourceFile
     * @param fileName
     * @throws Exception
     */
    private void compress(ZipOutputStream zos, File sourceFile, String fileName) throws Exception {
        if (sourceFile.isDirectory()) {
            // 如果是文件夹，取出文件夹中的文件（或子文件夹）
            File[] fileList = sourceFile.listFiles();
            if (fileList.length == 0)// 如果文件夹为空，则只需在目的地zip文件中写入一个目录进入点
            {
                zos.putNextEntry(new ZipEntry(fileName + "/"));
            } else// 如果文件夹不为空，则递归调用compress，文件夹中的每一个文件（或文件夹）进行压缩
            {
                for (File file : fileList) {
                    compress(zos, file, fileName + "/" + file.getName());
                }
            }
        } else {
            if (!sourceFile.exists()) {
                zos.putNextEntry(new ZipEntry("/"));
                zos.closeEntry();
            } else {
                // 单个文件，直接将其压缩到zip包中
                zos.putNextEntry(new ZipEntry(fileName));
                FileInputStream fis = new FileInputStream(sourceFile);
                byte[] buf = new byte[1024];
                int len;
                // 将源文件写入到zip文件中
                while ((len = fis.read(buf)) != -1) {
                    zos.write(buf, 0, len);
                }
                zos.closeEntry();
                fis.close();
            }
        }
    }

    /**
     * @Description: 文件下载zip
     * @date 2019年6月10日,下午4:40:11
     * @author huangshuai
     * @version v1.0
     * @param response
     * @param path
     * @param zipName
     * @throws IOException
     */
    public static void downLoadZipFile(HttpServletResponse response, String path, String zipName) throws IOException {
        try {
            File file = new File(path);
            response.setCharacterEncoding("UTF-8");
            response.setHeader("Content-Disposition",
                    "attachment; filename=" + new String(zipName.getBytes("UTF-8"), "ISO8859-1"));
            response.setContentLength((int) file.length());
            response.setContentType("application/zip");// 定义输出类型
            FileInputStream fis = new FileInputStream(file);
            BufferedInputStream buff = new BufferedInputStream(fis);
            byte[] b = new byte[1024];// 相当于我们的缓存
            long k = 0;// 该值用于计算当前实际下载了多少字节
            OutputStream myout = response.getOutputStream();// 从response对象中得到输出流,准备下载
            // 开始循环下载
            while (k < file.length()) {
                int j = buff.read(b, 0, 1024);
                k += j;
                myout.write(b, 0, j);
            }
            myout.flush();
            buff.close();
            file.delete();
        } catch (Exception e) {
            System.out.println(e);
        }
    }

    /**
     * @Description:删除文件及以下内容
     * @date 2019年6月10日,下午4:40:37
     * @author huangshuai
     * @version v1.0
     * @param folderPath
     */
    public static void delFolder(String folderPath) {
        try {
            delAllFile(folderPath); // 删除完里面所有内容
            String filePath = folderPath;
            filePath = filePath.toString();
            java.io.File myFilePath = new java.io.File(filePath);
            myFilePath.delete(); // 删除空文件夹
        } catch (Exception e) {
            e.printStackTrace();
        }
    }



    public static boolean delAllFile(String path) {
        boolean flag = false;
        File file = new File(path);
        if (!file.exists()) {
            return flag;
        }
        if (!file.isDirectory()) {
            return flag;
        }
        String[] tempList = file.list();
        File temp = null;
        for (int i = 0; i < tempList.length; i++) {
            if (path.endsWith(File.separator)) {
                temp = new File(path + tempList[i]);
            } else {
                temp = new File(path + File.separator + tempList[i]);
            }
            if (temp.isFile()) {
                temp.delete();
            }
            if (temp.isDirectory()) {
                delAllFile(path + "/" + tempList[i]);// 先删除文件夹里面的文件
                delFolder(path + "/" + tempList[i]);// 再删除空文件夹
                flag = true;
            }
        }
        return flag;
    }


}