package com.unis.app.service.Impl;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.collections.map.HashedMap;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.unis.accountability.businessmanagement.client.BizRespExaminationTaskClient;
import com.unis.accountability.businessmanagement.client.BizRespResponsibilityClient;
import com.unis.accountability.businessmanagement.common.vo.BizRespCheckExcelVO;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.backlog.ReceiverCollectionVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BilitySaveVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BilityUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BilityVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespCopyPfbVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilitPublishVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityCityVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityPageVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityPfbmcVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityUpdateVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.BizRespResponsibilityVO;
import com.unis.accountability.businessmanagement.common.vo.responsibility.PublishVO;
import com.unis.app.config.MyUserClient;
import com.unis.app.service.BizRespResponsibilityService;
import com.unis.app.service.BizRespUserService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;

import lombok.extern.slf4j.Slf4j;

/**粮食安全行政首长责任制-----考核评分表管理
 * @Auther:张新亮
 * @Date: 2019/9/18 0018 11:20
 * @Description:
 */
@Slf4j
@Service
public class BizRespResponsibilityServiceImpl implements BizRespResponsibilityService {

    @Autowired
    private BizRespResponsibilityClient bizRespResponsibilityClient;
    @Autowired
    private BizRespUserService bizRespUserService;
    @Autowired
    private MyUserClient myUserClient;
    @Autowired
    private BizRespExaminationTaskClient bizRespExaminationTaskClient;
    /**
     * 考核评分表管理---分页查询
     * @param pageVO
     * @param page
     * @param size
     * @return
     */
    @Override
    public ResponseWrapper findByPage(BizRespResponsibilityPageVO pageVO, Integer page, Integer size) {
        pageVO.setAreaCode(CurrentUtil.getAreaCode());
        ResponseWrapper responseWrapper= bizRespResponsibilityClient.findByPage(pageVO, page, size);
        if(responseWrapper.getInfoCode()==200){
          return responseWrapper;
        }
        return ResponseWrapper.error();
    }


    /**
     * 考核评分表管理------根据评分表名称和年分查询数据是否存在
     *
     * @return ResponseWrapper
     */
    @Override
    public ResponseWrapper findByPfbmc(BizRespResponsibilityPfbmcVO pfbmcVO) {
        return bizRespResponsibilityClient.findByPfbmc(pfbmcVO);
    }


    /**
     * 考核评分表管理------根据id查询明细
     * @param id
     * @return
     */
    @Override
    public ResponseWrapper findById(String year,String id) {
        String orgId=CurrentUtil.getOrgId();
        ResponseWrapper responseWrapper= bizRespResponsibilityClient.findById(year,id,orgId);
        return responseWrapper;
    }





    /**
     * 考核评分表管理------删除责任考核
     * @param ids
     * @return
     */
    @Override
    public ResponseWrapper deletes(String ids) {
        DeleteVO baseVO=new DeleteVO();
        baseVO.setId(ids);
        baseVO.setDeleteBy(CurrentUtil.getUserName());
        return bizRespResponsibilityClient.deletes(baseVO);
    }

    /**
     * 考核评分表管理---保存
     * @param bilityVO
     * @return
     */
    @Override
    public ResponseWrapper save(BilityVO bilityVO) {
        BilitySaveVO bilitySaveVO=new BilitySaveVO();
        bilitySaveVO.setCreateBy(CurrentUtil.getUserName());
        bilitySaveVO.setAreaCode(CurrentUtil.getAreaCode());
        bilitySaveVO.setDeptId(CurrentUtil.getDeptId());
        bilitySaveVO.setOrgId(CurrentUtil.getOrgId());
        bilitySaveVO.setBilityVO(bilityVO);
        return bizRespResponsibilityClient.save(bilitySaveVO);
    }


    /**
     * 考核评分表管理---编辑修改评分表名称
     * @param bilityVO
     * @return
     */
    @Override
    public ResponseWrapper updtae(BilityVO bilityVO) {
        BizRespResponsibilityVO bizRespResponsibilityVO= this.findByIds(bilityVO.getIds());
        if (!bizRespResponsibilityVO.getPfbmc().equals(bilityVO.getPfbmc())) {
            BizRespResponsibilityPfbmcVO responsibilityPfbmcVO=new BizRespResponsibilityPfbmcVO();
            responsibilityPfbmcVO.setYear(String.valueOf(bilityVO.getYear()));
            responsibilityPfbmcVO.setPfbmc(bilityVO.getPfbmc());
            ResponseWrapper responseWrapper= this.findByPfbmc(responsibilityPfbmcVO);
            if(responseWrapper.getInfoCode()!=200){
                //评分表名称已存在
                return responseWrapper;
            }
        }
        BilityUpdateVO  bilityUpdateVO=new BilityUpdateVO();
        bilityUpdateVO.setUpdateBy(CurrentUtil.getUserName());
        bilityUpdateVO.setBilityVO(bilityVO);
       return bizRespResponsibilityClient.update(bilityUpdateVO);
    }


    /**
     * 考核评分表管理---发布
     * @return
     */
    @Override
    public ResponseWrapper publish(PublishVO publish) {
        BizRespResponsibilitPublishVO publishVO =new BizRespResponsibilitPublishVO();
        publishVO.setId(publish.getId());
        publishVO.setUpdateBy(CurrentUtil.getUserName());
        //查询所有下属区粮办
        List<Map> mapList=bizRespUserService.findDataShiTree();
        System.out.println(mapList.toString());
        log.info(mapList.toString());
        if(CollectionUtils.isEmpty(mapList)) {
        	return ResponseWrapper.error( 500, "获取区粮办信息失败！" ,null);
        }
        List<String> areaCodeList=new ArrayList();
        Map<String,List<ReceiverCollectionVO>> mapUser = new HashedMap();
        for(Map map:mapList){
            String areaCode=map.get("areaCode").toString();
            mapUser.put(areaCode,new ArrayList<ReceiverCollectionVO>());
            areaCodeList.add(areaCode);
        }
        String areaCode= StringUtils.join(areaCodeList, ",");
        publishVO.setAreaCode(areaCode);
        publishVO.setAreaCodeList(mapList);

        publishVO.setItemName(publish.getItemName());
        publishVO.setUrl(publish.getUrl());
        publishVO.setUserName(CurrentUtil.getUserName());
       
        String userId = CurrentUtil.getUserId();
		publishVO.setUserId(userId);
        publishVO.setOrgName(CurrentUtil.getOrgName());
        List<ReceiverCollectionVO> userList = new ArrayList<>();
        
        
        
        //查询下面挂着的任务
        areaCodeList=new ArrayList();
        ResponseWrapper tasklistWrapper = bizRespExaminationTaskClient.findTaskListByResponsiBilityId(publish.getId());
        List<JSONObject> taskList = JSONArray.parseArray(tasklistWrapper.getData()+"", JSONObject.class);
        for(Map  map:mapList){
            String areaCodeType=map.get("areaCodeType").toString();
            areaCode=map.get("areaCode").toString();
            for(JSONObject task:taskList){
            	Double fnyfz = task.getDouble("fnyfz");
            	Double nyfz = task.getDouble("nyfz");
                if("fnyq".equals(areaCodeType) && !fnyfz.equals(0D)){
                    mapUser.put(areaCode,new ArrayList<ReceiverCollectionVO>());
                    areaCodeList.add(areaCode);
                }
                if("nyq".equals(areaCodeType) && !nyfz.equals(0D)){
                	mapUser.put(areaCode,new ArrayList<ReceiverCollectionVO>());
                	areaCodeList.add(areaCode);
                  
                }
                if(fnyfz.equals(0D) && nyfz.equals(0D)){
                	mapUser.put(areaCode,new ArrayList<ReceiverCollectionVO>());
                	areaCodeList.add(areaCode);
                	
                }
            }
		}
        //获取区粮办所有人
        ResponseWrapper wrapper = myUserClient.findUserByAreaCode(areaCodeList);
        System.out.println(wrapper.toString());
        log.info(wrapper.toString());
        if (wrapper.isSuccess() && !ObjectUtils.isEmpty(wrapper.getData())) {
            JSONArray objArr = JSON.parseArray(JsonUtils.serialize(wrapper.getData()));
            if (!ObjectUtils.isEmpty(objArr)) {
                objArr.forEach(jsonObj -> {
                    JSONObject obj = (JSONObject) jsonObj;
                    ReceiverCollectionVO receiverCollectionVO = new ReceiverCollectionVO();
                   
                    //如果包含当前发布用户则跳过
                    String userCodeStr = obj.getString("userCode");
                    if(userId.equals(userCodeStr) == false) {
                    	receiverCollectionVO.setUserId(userCodeStr);
                    	receiverCollectionVO.setUserName(obj.getString("userName"));
                    	receiverCollectionVO.setAreaCode(obj.getString("countyCode"));
                    	userList.add(receiverCollectionVO);
                    }
                    
                });
            }
        }
        mapUser = listToMap(mapUser,userList);
        System.out.println(mapUser.toString());
        log.info(mapUser.toString());
        publishVO.setUserList(mapUser);
        return bizRespResponsibilityClient.publish(publishVO);
    }
    public Map<String,List<ReceiverCollectionVO>> listToMap(Map<String,List<ReceiverCollectionVO>> map, List<ReceiverCollectionVO> userList){

        for(ReceiverCollectionVO receiverCollectionVO:userList){
            if(map.get(receiverCollectionVO.getAreaCode())!=null){
                map.get(receiverCollectionVO.getAreaCode()).add(receiverCollectionVO);
            }
        }
        return map;
    }

    /**
     * 考核评分表管理---下级州市
     * @param cityVO
     * @return
     */
    @Override
    public Map findByRespResponsibilityCity(BizRespResponsibilityCityVO cityVO) {
        List<Map> resultList=new ArrayList();
        cityVO.setAreaCode(CurrentUtil.getAreaCode());
        ResponseWrapper responseWrapper=bizRespResponsibilityClient.findByRespResponsibilityCity(cityVO);
        //查询已分配的州市
        String city= (String) responseWrapper.getData();
        List<String> zhoushiList=Arrays.asList(city.split(","));
        //所有州椒
        List<Map> unitList=bizRespUserService.findDataShiTree();
        //新增
        if("save".equals(cityVO.getType())){
            if(zhoushiList!=null && zhoushiList.size()>0){
                resultList= BizRespCheckExcelVO.getShiAreaCode(unitList, zhoushiList);
            }else{
                resultList=unitList;
            }
        }

        //修改
        if("update".equals(cityVO.getType())){
            //查询已分配的州市
            BizRespResponsibilityVO bizRespResponsibilityVO= findByInfo(cityVO.getResponsibilityId());
            if(zhoushiList!=null && zhoushiList.size()>0){
                resultList=BizRespCheckExcelVO.getShiAreaCode(unitList,zhoushiList);
            }
            //修改时合部所有州市
            List<String> cityList= bizRespResponsibilityVO.getShiAreaCode();
            List<Map> updateList=BizRespCheckExcelVO.getMergeCity(unitList,cityList);
            updateList.addAll(resultList);
            resultList=updateList;
        }

        //呼和浩特市、包头市、呼伦贝尔市、兴安盟、通辽市、赤峰市、乌兰察布市、鄂尔多斯市、巴彦淖尔市
        List<Map> lscq=new ArrayList();
        List<Map> lsfcq=new ArrayList();
        for(Map map:resultList){
            String shiname=map.get("orgName").toString();
            if("呼和浩特市".equals(shiname) || "包头市".equals(shiname)  || "呼伦贝尔市".equals(shiname)
                    || "兴安盟".equals(shiname) || "通辽市".equals(shiname) || "赤峰市".equals(shiname)
                    || "乌兰察布市".equals(shiname) || "鄂尔多斯市".equals(shiname) || "巴彦淖尔市".equals(shiname)
                    ){
                lscq.add(map);
            }else{
                lsfcq.add(map);
            }
        }
        Map map=new HashMap();
        map.put("lscq",lscq);
        map.put("lsfcq", lsfcq);
        return map;
    }

    /**
     * 考核评分表管理---更新评分表
     * @param updateVO
     * @return
     */
    @Override
    public ResponseWrapper updatePfb(BizRespResponsibilityUpdateVO updateVO) {
        updateVO.setUpdateBy(CurrentUtil.getUserName());
        return bizRespResponsibilityClient.updatePfb(updateVO);
    }


    /**
     * 考核评分表管理------根据ID查询基本信息
     * @param id
     * @return
     */
    @Override
    public BizRespResponsibilityVO findByInfo(String id) {
        ResponseWrapper responseWrapper1=bizRespResponsibilityClient.findByInfo(id);
        String dataJson = (String) responseWrapper1.getData();
        BizRespResponsibilityVO bizRespResponsibilityVO= JSON.parseObject(dataJson,BizRespResponsibilityVO.class);
        if(bizRespResponsibilityVO!=null){
            String area=bizRespUserService.getCity(bizRespResponsibilityVO.getShiAreaCode());
            bizRespResponsibilityVO.setShiAreaCodeName(area);
        }
        return bizRespResponsibilityVO;
    }


    /**
     * 考核评分表管理----根据id查询明细
     * @param id
     * @return
     */
    @Override
    public BizRespResponsibilityVO findByIds(String id) {
        ResponseWrapper responseWrapper=bizRespResponsibilityClient.findByIds(id);
        String dataJson = (String) responseWrapper.getData();
        BizRespResponsibilityVO bizRespResponsibilityVO= JSON.parseObject(dataJson,BizRespResponsibilityVO.class);
        if(bizRespResponsibilityVO!=null){
            String area=bizRespUserService.getCity(bizRespResponsibilityVO.getShiAreaCode());
            bizRespResponsibilityVO.setShiAreaCodeName(area);
        }
        return bizRespResponsibilityVO;
    }



    /**
     * 考核评分表管理------根据年分查询基本信息
     * @param year
     * @return
     */
    @Override
    public BizRespResponsibilityVO findByYear(String year) {
        ResponseWrapper responseWrapper=bizRespResponsibilityClient.findByYear(year);
        String dataJson = (String) responseWrapper.getData();
        BizRespResponsibilityVO bizRespResponsibilityVO= JSON.parseObject(dataJson,BizRespResponsibilityVO.class);
//        if(bizRespResponsibilityVO!=null){
//            String area=bizRespUserService.getCity(bizRespResponsibilityVO.getShiAreaCode());
//            bizRespResponsibilityVO.setShiAreaCodeName(area);
//        }
        return bizRespResponsibilityVO;
    }






    /**
     * 考核评分表管理---下发评表明细
     * @param pageVO
     * @return
     */
    @Override
    public ResponseWrapper findByRespResponsibilityInfo(BizRespResponsibilityPageVO pageVO) {
        pageVO.setAreaCode(CurrentUtil.getAreaCode());
        return bizRespResponsibilityClient.findByRespResponsibilityInfo(pageVO);
    }

    /**
     * 考核评分表管理------复制评分表
     * @param copyPfbVO
     * @return
     */
    @Override
    public ResponseWrapper saveCopyPfb(BizRespCopyPfbVO copyPfbVO) {
        return bizRespResponsibilityClient.saveCopyPfb(copyPfbVO);
    }


    /**
     * 考核评分表管理---状态
     * @return
     */
    @Override
    public List<Map> findByStatus() {
        List<Map> mapList=new ArrayList();
        Map map=new HashMap();
        map.put("ID","10");
        map.put("NAME","未录入");
        mapList.add(map);
        map=new HashMap();
        map.put("ID","20");
        map.put("NAME","已录入");
        mapList.add(map);
        map=new HashMap();
        map.put("ID","30");
        map.put("NAME","已上报");
        mapList.add(map);
        map=new HashMap();
        map.put("ID","50");
        map.put("NAME","已审核");
        mapList.add(map);
        return mapList;
    }




}