package com.unis.app.service.Impl;

import com.alibaba.fastjson.JSON;
import com.unis.accountability.businessmanagement.client.MsgNoticeClient;
import com.unis.accountability.businessmanagement.common.vo.DeleteVO;
import com.unis.accountability.businessmanagement.common.vo.FileVO;
import com.unis.accountability.businessmanagement.common.vo.msgNotice.*;
import com.unis.app.service.BizRespFileService;
import com.unis.app.service.BizRespUserService;
import com.unis.app.service.MsgNoticeService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.ResponseWrapper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
 * @Auther:张新亮
 * @Date: 2019/11/5 0005 15:05
 * @Description:
 */
@Service
public class MsgNoticeServiceImpl implements MsgNoticeService {

    @Autowired
    private MsgNoticeClient msgNoticeClient;
    @Autowired
    private BizRespFileService bizRespFileService;
    @Autowired
    private BizRespUserService bizRespUserService;

    /**
     * 信息报送----保存
     * @param msgNoticeVO
     * @return
     */
    @Override
    public ResponseWrapper save(MsgNoticeVO msgNoticeVO) {
        MsgNoticeSaveVO saveVO=new MsgNoticeSaveVO();
        saveVO.setCreateBy(CurrentUtil.getUserName());
        saveVO.setAreaCode(CurrentUtil.getAreaCode());
        saveVO.setOrgId(CurrentUtil.getOrgId());
        saveVO.setDeptId(CurrentUtil.getDeptId());
        saveVO.setMsgNoticeVO(msgNoticeVO);
        return msgNoticeClient.save(saveVO);
    }

    /**
     * 信息报送---报送
     * @param id
     */
    @Override
    public ResponseWrapper publish(MsgNoticePublishVO publishVO) {
        publishVO.setUpdateBy(CurrentUtil.getUserName());
        return msgNoticeClient.publish(publishVO);
    }

    /**
     * 信息报送---批量采用
     * @param idsList
     * @return
     */
    @Override
    public ResponseWrapper publishALL(MsgNoticePublishVO publishVO) {
        publishVO.setUpdateBy(CurrentUtil.getUserName());
        return msgNoticeClient.publishALL(publishVO);
    }




    /**
     * 信息报送----查看
     * @param id
     * @param status
     * @return
     */
    @Override
    public MsgNoticeVO findById(String id) {
        ResponseWrapper responseWrapper=msgNoticeClient.findById(id);
        String dataJson= (String) responseWrapper.getData();
        MsgNoticeVO msgNoticeVO= JSON.parseObject(dataJson, MsgNoticeVO.class);
        //下载文件封装集合
        String fileId= StringUtils.join(msgNoticeVO.getFileId(), ",");
        List<FileVO> fileVOList=bizRespFileService.getFileInfo(fileId);
        msgNoticeVO.setFileList(fileVOList);
        return msgNoticeVO;
    }

    /**
     * 信息报送----查看
     * @param id
     * @return
     */
    @Override
    public MsgNoticeVO findByInfo(String id) {
        ResponseWrapper responseWrapper=msgNoticeClient.findByInfo(id);
        String dataJson= (String) responseWrapper.getData();
        MsgNoticeVO msgNoticeVO= JSON.parseObject(dataJson, MsgNoticeVO.class);
        return msgNoticeVO;
    }


    /***
     * 信息报送----分页
     * @param msgNoticePage
     * @param page
     * @param size
     * @return
     */
    @Override
    public Map findByPage(MsgNoticePage msgNoticePage, Integer page, Integer size) {
        msgNoticePage.setAreaCode(CurrentUtil.getAreaCode());
        ResponseWrapper responseWrapper=msgNoticeClient.findByPage(msgNoticePage, page, size);
        String dataJson= (String) responseWrapper.getData();
        Map map= JSON.parseObject(dataJson, Map.class);
        if(map!=null){
            String listJson=JSON.toJSONString(map.get("list"));
            List<Map> mapList= JSON.parseArray(listJson, Map.class);
            for(Map data:mapList){
                String orgId=data.get("org_id").toString();
                String orgName=bizRespUserService.findByCode(orgId);
                data.put("orgName",orgName);
            }
            map.put("list", mapList);
        }
        return map;
    }


    /**
     * 信息报送----修改
     * @param msgNoticeVO
     * @return
     */
    @Override
    public ResponseWrapper update(MsgNoticeVO msgNoticeVO) {
        MsgNoticeUpdateVO updateVO=new MsgNoticeUpdateVO();
        updateVO.setUpdateBy(CurrentUtil.getUserName());
        updateVO.setMsgNoticeVO(msgNoticeVO);
        return msgNoticeClient.update(updateVO);
    }

    /**
     * 信息报送---删除
     */
    @Override
    public ResponseWrapper deletes(String[] ids ) {
        DeleteVO deleteVO=new DeleteVO();
        deleteVO.setDeleteBy(CurrentUtil.getUserName());
        deleteVO.setIds(ids);
        return msgNoticeClient.deletes(deleteVO);
    }



}