package com.unis.app.service.Impl;

import com.alibaba.fastjson.JSON;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.unis.accountability.businessmanagement.client.BizRespExaminationTaskClient;
import com.unis.accountability.businessmanagement.client.ProvinceLeadDeptClient;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskQueryVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.BigTaskVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.ProvinceLeadVO;
import com.unis.accountability.businessmanagement.common.vo.examinationTask.TaskInfoVO;
import com.unis.accountability.businessmanagement.common.vo.opinion.BizRespDepartmentalOpinionVO;
import com.unis.app.service.BizRespUserService;
import com.unis.app.service.ProvinceLeadDeptService;
import com.unis.common.utils.CurrentUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/9/21 17:35
 * Version 1.0
 */
@Service
@Slf4j
public class ProvinceLeadDeptServiceImpl implements ProvinceLeadDeptService {

    @Autowired
    private ProvinceLeadDeptClient provinceLeadDeptClient;
    @Autowired
    private BizRespExaminationTaskClient taskClient;
    @Autowired
    private BizRespUserService bizRespUserService;

    @Override
    public ResponseWrapper getProvinceLeadDeptDetail(String id, String areaCode, String coordinateDeptId) {
        BigTaskVO bigTaskVO = new BigTaskVO();

        //获得省级配合部门意见
        ResponseWrapper rw = provinceLeadDeptClient.getProvinceCoordinateOpinion(id, areaCode, coordinateDeptId);
        if (rw.getInfoCode() != 200) {
            return rw;
        }
        List<BizRespDepartmentalOpinionVO> managerVOList = JsonUtils.parseList(JsonUtils.serialize(rw.getData()), BizRespDepartmentalOpinionVO.class);
        if (managerVOList != null && managerVOList.size() > 0) {
            for (BizRespDepartmentalOpinionVO opinionVO : managerVOList) {
                //获得配合部门名称
                String deptName = bizRespUserService.findByQtbmName(opinionVO.getDeptId(), CurrentUtil.getOrgId());
                opinionVO.setDeptId(deptName);
            }
        }
        bigTaskVO.setCoordinateOpinionList(managerVOList);

        //获得省级牵头部门意见
        ResponseWrapper rw1 = provinceLeadDeptClient.getProvinceLeadOpinion(id, areaCode);
        if (rw1.getInfoCode() != 200) {
            return rw1;
        }
        BizRespDepartmentalOpinionVO opinionVO = JsonUtils.parse(JsonUtils.serialize(rw1.getData()), BizRespDepartmentalOpinionVO.class);
        if (opinionVO != null) {
            //获得牵头部门名称
            String deptName = bizRespUserService.findByQtbmName(opinionVO.getDeptId(), CurrentUtil.getOrgId());
            opinionVO.setDeptId(deptName);
        }
        bigTaskVO.setLeadOpinion(opinionVO);

        //获得省级牵头部门复评意见
        ResponseWrapper rw3 = provinceLeadDeptClient.getProvinceLeadAgainOpinion(id, areaCode);
        if (rw3.getInfoCode() != 200) {
            return rw3;
        }
        BizRespDepartmentalOpinionVO opinionAgainVO = JsonUtils.parse(JsonUtils.serialize(rw3.getData()), BizRespDepartmentalOpinionVO.class);
        if (opinionAgainVO.getDeptId() != null) {
            //获得配合部门名称
            String deptName = bizRespUserService.findByQtbmName(opinionAgainVO.getDeptId(), CurrentUtil.getOrgId());
            opinionAgainVO.setDeptId(deptName);
            bigTaskVO.setLeadAgainOpinion(opinionAgainVO);
        }


        //获得考核目标任务明细
        ResponseWrapper rw2 = taskClient.findByTaskInfo(id);
        if (rw2.getInfoCode() != 200) {
            return rw2;
        }
        String dataJson = (String) rw2.getData();
        TaskInfoVO taskInfoVO = JSON.parseObject(dataJson, TaskInfoVO.class);
        bigTaskVO.setTaskInfoVO(taskInfoVO);

        return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", bigTaskVO);
    }

    @Override
    public ResponseWrapper getProvinceCoordinateDeptDetail(String id, String areaCode, String coordinateDeptId) {
        BigTaskVO bigTaskVO = new BigTaskVO();

        //获得省级配合部门意见
        ResponseWrapper rw = provinceLeadDeptClient.getProvinceCoordinateOpinion(id, areaCode, coordinateDeptId);
        if (rw.getInfoCode() != 200) {
            return rw;
        }
        List<BizRespDepartmentalOpinionVO> opinionVOList = JsonUtils.parseList(JsonUtils.serialize(rw.getData()), BizRespDepartmentalOpinionVO.class);
        if (opinionVOList != null && opinionVOList.size() > 0) {

            //查询所有牵头/配合部门名称
            StringBuilder qtbmNames = null;
            List<Map> mapList = null;
            String orgId = CurrentUtil.getOrgId();
            mapList = bizRespUserService.findByQtbmAndPhbm(orgId);

            for (BizRespDepartmentalOpinionVO opinionVO : opinionVOList) {
                //获得配合部门名称
                String coordinationDepartment = opinionVO.getDeptId();
                String wbphbmName = getWbbmName(mapList, coordinationDepartment);
                if (StringUtils.isNotEmpty(wbphbmName)) {
                    opinionVO.setDeptId(wbphbmName);
                }
            }
        }

        bigTaskVO.setCoordinateOpinionList(opinionVOList);

        //获得考核目标任务明细
        ResponseWrapper rw2 = taskClient.findByTaskInfo(id);
        if (rw.getInfoCode() != 200) {
            return rw2;
        }
        String dataJson = (String) rw2.getData();
        TaskInfoVO taskInfoVO = JSON.parseObject(dataJson, TaskInfoVO.class);
        bigTaskVO.setTaskInfoVO(taskInfoVO);

        return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", bigTaskVO);
    }

    @Override
    public ResponseWrapper getProvinceLeadDept(BigTaskQueryVO bigTaskQueryVO, Integer pageNum, Integer pageSize) {
        bigTaskQueryVO.setDeptId(CurrentUtil.getDeptId());
        ResponseWrapper rw = provinceLeadDeptClient.getProvinceLeadDept(bigTaskQueryVO, pageNum, pageSize);
        if (rw.getInfoCode() != 200) {
            return rw;
        }
        Map<String, Object> resultMap = JsonUtils.parseMap(JsonUtils.serialize(rw.getData()), String.class, Object.class);
        List<ProvinceLeadVO> list = (List<ProvinceLeadVO>) resultMap.get("provinceLeadVOList");

        ObjectMapper mapper = new ObjectMapper();
        List<ProvinceLeadVO> provinceLeadVOList = mapper.convertValue(list, new TypeReference<List<ProvinceLeadVO>>() {
        });

        //查询所有牵头/配合部门名称
        StringBuilder qtbmNames = null;
        List<Map> mapList = null;
        String orgId = CurrentUtil.getOrgId();
        mapList = bizRespUserService.findByQtbmAndPhbm(orgId);

        if (provinceLeadVOList != null && !provinceLeadVOList.isEmpty()) {
            for (ProvinceLeadVO provinceLeadVO : provinceLeadVOList) {
                String leadDepartment = provinceLeadVO.getLeadDepartment();
                //牵头部门名称
                String wbqtbmName = getWbbmName(mapList, leadDepartment);
                if (StringUtils.isNotEmpty(wbqtbmName)) {
                    provinceLeadVO.setLeadDepartment(wbqtbmName);
                }

                //配合部门名称
                String coordinationDepartment = provinceLeadVO.getCoordinationDepartment();
                String wbphbmName = getWbbmName(mapList, coordinationDepartment);
                if (StringUtils.isNotEmpty(wbphbmName)) {
                    provinceLeadVO.setCoordinationDepartment(wbphbmName);
                }

            }
        }

        Map<String, Object> map = new HashMap<>();
        map.put("total", resultMap.get("total"));
        map.put("provinceLeadVOList", provinceLeadVOList);
        return ResponseWrapper.success(HttpStatus.OK.value(), "查询成功", map);
    }


    /**
     * 获得外部部门名称
     *
     * @param mapList
     * @param department
     * @return
     */
    public String getWbbmName(List<Map> mapList, String department) {
        StringBuilder qtbmNames = new StringBuilder();
        String[] ldArr = null;
        if (department.contains(",")) {
            ldArr = department.split(",");
        } else {
            ldArr = new String[]{department};
        }
        for (int i = 0; i < ldArr.length; i++) {
            for (Map nameMap : mapList) {
                if (ldArr[i].equals(nameMap.get("ID"))) {
                    qtbmNames.append(nameMap.get("NAME")).append(",");
                }
            }
        }
        if (StringUtils.isNotEmpty(qtbmNames.toString())) {
            return qtbmNames.deleteCharAt(qtbmNames.length() - 1).toString();
        } else {
            return null;
        }

    }
}
